(************** Content-type: application/mathematica **************

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     81751,       3283]*)
(*NotebookOutlinePosition[     84081,       3349]*)
(*  CellTagsIndexPosition[     83796,       3337]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Style Definitions", "Subtitle"],

Cell["\<\
Modify the definitions below to change the default appearance of all cells in \
a given style.  Make modifications to any definition using commands in the \
Format menu.\
\>", "Text"],

Cell[CellGroupData[{

Cell["Style Environment Names", "Section"],

Cell[StyleData[All, "Working"],
  PageWidth->WindowWidth,
  ShowCellBracket->False,
  CellLabelMargins->{{10, Inherited}, {Inherited, Inherited}},
  ScriptMinSize->9],

Cell[StyleData[All, "AllBrackets"],
  PageWidth->WindowWidth,
  ShowCellBracket->True,
  ScriptMinSize->9],

Cell[StyleData[All, "Presentation"],
  PageWidth->WindowWidth,
  ShowCellBracket->False,
  ShowGroupOpenCloseIcon->True,
  ScriptMinSize->9],

Cell[StyleData[All, "Printout"],
  PageWidth->PaperWidth,
  ShowCellBracket->False,
  CellLabelMargins->{{2, Inherited}, {Inherited, Inherited}},
  ScriptMinSize->5,
  PrivateFontOptions->{"FontType"->"Outline"}],

Cell[StyleData[All, "EnhancedPrintout"],
  PageWidth->PaperWidth,
  ShowCellBracket->False,
  CellLabelMargins->{{2, Inherited}, {Inherited, Inherited}},
  ScriptMinSize->5,
  PrivateFontOptions->{"FontType"->"Outline"}],

Cell[StyleData[All, "EnhancedPrintoutNonGray"],
  PageWidth->PaperWidth,
  ShowCellBracket->False,
  CellLabelMargins->{{2, Inherited}, {Inherited, Inherited}},
  ScriptMinSize->5,
  PrivateFontOptions->{"FontType"->"Outline"}]
}, Closed]],

Cell[CellGroupData[{

Cell["Notebook Options", "Section"],

Cell["\<\
The options defined for the style below will be used at the Notebook level.\
\>", "Text"],

Cell[StyleData["Notebook"],
  PrintingStyleEnvironment->"Printout",
  PageHeaders->{{Cell[ 
          TextData[ {
            CounterBox[ "Page"]}], "PageNumber"], None, Cell[ 
          TextData[ {
            ValueBox[ "FileName"]}], "Header"]}, {Cell[ 
          TextData[ {
            ValueBox[ "FileName"]}], "Header"], None, Cell[ 
          TextData[ {
            CounterBox[ "Page"]}], "PageNumber"]}},
  PrintingOptions->{"PrintingMargins"->{{97, 97}, {180, 64}},
  "FirstPageHeader"->False,
  "FacingPages"->True},
  CellLabelAutoDelete->False,
  CellFrameLabelMargins->6,
  StyleMenuListing->None]
}, Closed]],

Cell[CellGroupData[{

Cell["Styles for Headings", "Section"],

Cell[CellGroupData[{

Cell[StyleData["Title"],
  CellMargins->{{12, Inherited}, {20, 40}},
  CellGroupingRules->{"TitleGrouping", 0},
  PageBreakAbove->True,
  PageBreakBelow->False,
  LineSpacing->{1, 11},
  CounterIncrements->"Title",
  CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
      "Subtitle", 0}, {"Subsubtitle", 0}},
  FontFamily->"Helvetica",
  FontSize->36,
  FontWeight->"Bold"],

Cell[StyleData["Title", "Printout"],
  CellMargins->{{2, 10}, {15, 30}},
  FontSize->30],

Cell[StyleData["Title", "EnhancedPrintout"],
  CellMargins->{{2, 10}, {15, 30}},
  FontFamily->"Futura",
  FontSize->30],

Cell[StyleData["Title", "EnhancedPrintoutNonGray"],
  CellMargins->{{2, 10}, {15, 30}},
  FontFamily->"Futura",
  FontSize->30]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Subtitle"],
  CellMargins->{{12, Inherited}, {10, 2}},
  CellGroupingRules->{"TitleGrouping", 10},
  PageBreakBelow->False,
  LineSpacing->{1, 11},
  CounterIncrements->"Subtitle",
  CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
      "Subsubtitle", 0}},
  FontFamily->"Helvetica",
  FontSize->28],

Cell[StyleData["Subtitle", "Printout"],
  CellMargins->{{2, 10}, {10, 15}},
  FontSize->24],

Cell[StyleData["Subtitle", "EnhancedPrintout"],
  CellMargins->{{2, 10}, {10, 15}},
  FontFamily->"Futura",
  FontSize->24],

Cell[StyleData["Subtitle", "EnhancedPrintoutNonGray"],
  CellMargins->{{2, 10}, {10, 15}},
  FontFamily->"Futura",
  FontSize->24]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Subsubtitle"],
  CellMargins->{{12, Inherited}, {10, 20}},
  CellGroupingRules->{"TitleGrouping", 20},
  PageBreakBelow->False,
  CounterIncrements->"Subsubtitle",
  CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}},
  FontFamily->"Helvetica",
  FontSize->14,
  FontSlant->"Italic"],

Cell[StyleData["Subsubtitle", "Printout"],
  CellMargins->{{2, 10}, {8, 10}},
  FontSize->12],

Cell[StyleData["Subsubtitle", "EnhancedPrintout"],
  CellMargins->{{2, 10}, {8, 10}},
  FontFamily->"Futura",
  FontSize->12],

Cell[StyleData["Subsubtitle", "EnhancedPrintoutNonGray"],
  CellMargins->{{2, 10}, {8, 10}},
  FontFamily->"Futura",
  FontSize->12]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Section"],
  CellFrame->{{0, 0}, {0.5, 0}},
  CellMargins->{{10, Inherited}, {8, 30}},
  CellGroupingRules->{"SectionGrouping", 30},
  PageBreakBelow->False,
  CellFrameMargins->8,
  LineSpacing->{1, 7},
  CounterIncrements->"Section",
  CounterAssignments->{{"Subsection", 0}, {"Subsubsection", 0}},
  FontFamily->"Helvetica",
  FontSize->20,
  FontWeight->"Bold",
  CellTags->"Section"],

Cell[StyleData["Section", "Printout"],
  CellMargins->{{2, 0}, {7, 24}},
  FontSize->16],

Cell[StyleData["Section", "EnhancedPrintout"],
  CellMargins->{{2, 0}, {7, 24}},
  FontFamily->"Futura",
  FontSize->16],

Cell[StyleData["Section", "EnhancedPrintoutNonGray"],
  CellMargins->{{2, 0}, {7, 24}},
  FontFamily->"Futura",
  FontSize->16]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Subsection"],
  CellDingbat->"\[FilledSquare]",
  CellMargins->{{24, Inherited}, {8, 30}},
  CellGroupingRules->{"SectionGrouping", 40},
  PageBreakBelow->False,
  CounterIncrements->"Subsection",
  CounterAssignments->{{"Subsubsection", 0}},
  FontFamily->"Helvetica",
  FontSize->14,
  FontWeight->"Bold",
  CellTags->"Subsection"],

Cell[StyleData["Subsection", "Printout"],
  CellMargins->{{9, 0}, {7, 24}},
  FontSize->12],

Cell[StyleData["Subsection", "EnhancedPrintout"],
  CellMargins->{{9, 0}, {7, 24}},
  FontFamily->"Futura",
  FontSize->14],

Cell[StyleData["Subsection", "EnhancedPrintoutNonGray"],
  CellMargins->{{9, 0}, {7, 24}},
  FontFamily->"Futura",
  FontSize->14]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Subsubsection"],
  CellMargins->{{12, Inherited}, {8, 24}},
  CellGroupingRules->{"SectionGrouping", 50},
  PageBreakBelow->False,
  CounterIncrements->"Subsubsection",
  FontFamily->"Helvetica",
  FontWeight->"Bold",
  CellTags->"Subsubsection"],

Cell[StyleData["Subsubsection", "Printout"],
  CellMargins->{{2, 0}, {7, 18}},
  FontSize->10],

Cell[StyleData["Subsubsection", "EnhancedPrintout"],
  CellMargins->{{2, 0}, {7, 18}},
  FontFamily->"Futura",
  FontSize->10],

Cell[StyleData["Subsubsection", "EnhancedPrintoutNonGray"],
  CellMargins->{{2, 0}, {7, 18}},
  FontFamily->"Futura",
  FontSize->10]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Styles for Body Text", "Section"],

Cell[CellGroupData[{

Cell[StyleData["Text"],
  CellMargins->{{12, 10}, {7, 7}},
  LineSpacing->{1, 3},
  ParagraphSpacing->{0.7, 0},
  CounterIncrements->"Text"],

Cell[StyleData["Text", "Printout"],
  CellMargins->{{2, 2}, {6, 6}},
  TextJustification->1,
  FontSize->11],

Cell[StyleData["Text", "EnhancedPrintout"],
  CellMargins->{{2, 2}, {6, 6}},
  TextJustification->1,
  FontFamily->"Palatino",
  FontSize->10],

Cell[StyleData["Text", "EnhancedPrintoutNonGray"],
  CellMargins->{{2, 2}, {6, 6}},
  TextJustification->1,
  FontFamily->"Palatino",
  FontSize->10]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["SmallText"],
  CellMargins->{{12, 10}, {6, 6}},
  LineSpacing->{1, 3},
  ParagraphSpacing->{0.7, 0},
  CounterIncrements->"SmallText",
  FontSize->9],

Cell[StyleData["SmallText", "Printout"],
  CellMargins->{{2, 2}, {5, 5}},
  TextJustification->1,
  FontSize->7],

Cell[StyleData["SmallText", "EnhancedPrintout"],
  CellMargins->{{2, 2}, {5, 5}},
  TextJustification->1,
  FontFamily->"Palatino",
  FontSize->7],

Cell[StyleData["SmallText", "EnhancedPrintoutNonGray"],
  CellMargins->{{2, 2}, {5, 5}},
  TextJustification->1,
  FontFamily->"Palatino",
  FontSize->7]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["CopyrightText"],
  CellMargins->{{10, 4}, {0, 8}},
  ParagraphSpacing->{0, 0},
  StyleMenuListing->None,
  FontFamily->"Helvetica",
  FontSize->10],

Cell[StyleData["CopyrightText", "Printout"],
  CellMargins->{{2, 0}, {0, 8}},
  FontSize->8]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Styles for Input/Output", "Section"],

Cell["\<\
The cells in this section define styles used for input and output to the \
kernel.  Be careful when modifying, renaming, or removing these styles, \
because the front end associates special meanings with these style names.\
\>", "Text"],

Cell[CellGroupData[{

Cell[StyleData["Input"],
  ShowCellBracket->True,
  CellMargins->{{45, 10}, {5, 7}},
  Evaluatable->True,
  CellGroupingRules->"InputGrouping",
  CellHorizontalScrolling->True,
  PageBreakWithin->False,
  GroupPageBreakWithin->False,
  DefaultFormatType->DefaultInputFormatType,
  AutoItalicWords->{},
  FormatType->InputForm,
  ShowStringCharacters->True,
  NumberMarks->True,
  CounterIncrements->"Input",
  FontWeight->"Bold"],

Cell[StyleData["Input", "Printout"],
  ShowCellBracket->False,
  CellMargins->{{39, 0}, {4, 6}},
  FontSize->9],

Cell[StyleData["Input", "EnhancedPrintout"],
  ShowCellBracket->False,
  CellMargins->{{39, 0}, {4, 6}},
  FontSize->9],

Cell[StyleData["Input", "EnhancedPrintoutNonGray"],
  ShowCellBracket->False,
  CellMargins->{{39, 0}, {4, 6}},
  FontSize->9]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Output"],
  ShowCellBracket->True,
  CellMargins->{{46, 10}, {7, 5}},
  CellEditDuplicate->True,
  CellGroupingRules->"OutputGrouping",
  CellHorizontalScrolling->True,
  PageBreakWithin->False,
  GroupPageBreakWithin->False,
  GeneratedCell->True,
  CellAutoOverwrite->True,
  DefaultFormatType->DefaultOutputFormatType,
  AutoItalicWords->{},
  FormatType->InputForm,
  CounterIncrements->"Output"],

Cell[StyleData["Output", "Printout"],
  ShowCellBracket->False,
  CellMargins->{{39, 0}, {6, 4}},
  FontSize->9],

Cell[StyleData["Output", "EnhancedPrintout"],
  ShowCellBracket->False,
  CellMargins->{{39, 0}, {6, 4}},
  FontSize->9],

Cell[StyleData["Output", "EnhancedPrintoutNonGray"],
  ShowCellBracket->False,
  CellMargins->{{39, 0}, {6, 4}},
  FontSize->9]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Message"],
  ShowCellBracket->True,
  CellMargins->{{45, Inherited}, {Inherited, Inherited}},
  CellGroupingRules->"OutputGrouping",
  PageBreakWithin->False,
  GroupPageBreakWithin->False,
  GeneratedCell->True,
  CellAutoOverwrite->True,
  ShowCellLabel->False,
  CellLabelMargins->{{11, Inherited}, {Inherited, Inherited}},
  DefaultFormatType->DefaultOutputFormatType,
  AutoItalicWords->{},
  FormatType->InputForm,
  CounterIncrements->"Message",
  StyleMenuListing->None,
  FontSlant->"Italic",
  FontColor->RGBColor[1, 0, 0]],

Cell[StyleData["Message", "Printout"],
  ShowCellBracket->False,
  CellMargins->{{39, Inherited}, {Inherited, Inherited}},
  FontSize->9,
  FontColor->GrayLevel[0]],

Cell[StyleData["Message", "EnhancedPrintout"],
  ShowCellBracket->False,
  CellMargins->{{39, Inherited}, {Inherited, Inherited}},
  FontFamily->"Courier",
  FontSize->9,
  FontColor->GrayLevel[0]],

Cell[StyleData["Message", "EnhancedPrintoutNonGray"],
  ShowCellBracket->False,
  CellMargins->{{39, Inherited}, {Inherited, Inherited}},
  FontFamily->"Courier",
  FontSize->9,
  FontColor->GrayLevel[0]]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Print"],
  ShowCellBracket->True,
  CellMargins->{{75, Inherited}, {Inherited, Inherited}},
  CellGroupingRules->"OutputGrouping",
  CellHorizontalScrolling->True,
  PageBreakWithin->False,
  GroupPageBreakWithin->False,
  GeneratedCell->True,
  CellAutoOverwrite->True,
  ShowCellLabel->False,
  CellLabelMargins->{{11, Inherited}, {Inherited, Inherited}},
  DefaultFormatType->DefaultOutputFormatType,
  AutoItalicWords->{},
  FormatType->InputForm,
  CounterIncrements->"Print",
  StyleMenuListing->None],

Cell[StyleData["Print", "Printout"],
  ShowCellBracket->False,
  CellMargins->{{57, Inherited}, {Inherited, Inherited}},
  FontSize->9],

Cell[StyleData["Print", "EnhancedPrintout"],
  ShowCellBracket->False,
  CellMargins->{{57, Inherited}, {Inherited, Inherited}},
  FontFamily->"Courier",
  FontSize->9],

Cell[StyleData["Print", "EnhancedPrintoutNonGray"],
  ShowCellBracket->False,
  CellMargins->{{57, Inherited}, {Inherited, Inherited}},
  FontFamily->"Courier",
  FontSize->9]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Graphics"],
  ShowCellBracket->True,
  CellMargins->{{47, Inherited}, {Inherited, Inherited}},
  CellGroupingRules->"GraphicsGrouping",
  CellHorizontalScrolling->True,
  PageBreakWithin->False,
  GeneratedCell->True,
  CellAutoOverwrite->True,
  ShowCellLabel->False,
  DefaultFormatType->DefaultOutputFormatType,
  FormatType->InputForm,
  CounterIncrements->"Graphics",
  StyleMenuListing->None],

Cell[StyleData["Graphics", "Printout"],
  ShowCellBracket->False,
  CellMargins->{{39, Inherited}, {Inherited, Inherited}},
  ImageSize->{250, 250},
  FontSize->9],

Cell[StyleData["Graphics", "EnhancedPrintout"],
  ShowCellBracket->False,
  CellMargins->{{39, Inherited}, {Inherited, Inherited}},
  ImageSize->{250, 250},
  FontFamily->"Courier",
  FontSize->9],

Cell[StyleData["Graphics", "EnhancedPrintoutNonGray"],
  ShowCellBracket->False,
  CellMargins->{{39, Inherited}, {Inherited, Inherited}},
  ImageSize->{250, 250},
  FontFamily->"Courier",
  FontSize->9]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["CellLabel"],
  StyleMenuListing->None,
  FontFamily->"Helvetica",
  FontSize->9,
  FontColor->RGBColor[0, 0, 1]],

Cell[StyleData["CellLabel", "Printout"],
  FontFamily->"Courier",
  FontSize->8,
  FontSlant->"Italic",
  FontColor->GrayLevel[0]],

Cell[StyleData["CellLabel", "EnhancedPrintout"],
  FontFamily->"Courier",
  FontSize->8,
  FontSlant->"Italic",
  FontColor->GrayLevel[0]],

Cell[StyleData["CellLabel", "EnhancedPrintoutNonGray"],
  FontFamily->"Courier",
  FontSize->8,
  FontSlant->"Italic",
  FontColor->GrayLevel[0]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Inline Formatting", "Section"],

Cell["\<\
These styles are for modifying individual words or letters in a cell \
exclusive of the cell tag.\
\>", "Text"],

Cell[StyleData["RM"],
  StyleMenuListing->None,
  FontWeight->"Plain",
  FontSlant->"Plain"],

Cell[StyleData["BF"],
  StyleMenuListing->None,
  FontWeight->"Bold"],

Cell[StyleData["IT"],
  StyleMenuListing->None,
  FontSlant->"Italic"],

Cell[StyleData["TR"],
  StyleMenuListing->None,
  FontFamily->"Times",
  FontWeight->"Plain",
  FontSlant->"Plain"],

Cell[StyleData["TI"],
  StyleMenuListing->None,
  FontFamily->"Times",
  FontWeight->"Plain",
  FontSlant->"Italic"],

Cell[StyleData["TB"],
  StyleMenuListing->None,
  FontFamily->"Times",
  FontWeight->"Bold",
  FontSlant->"Plain"],

Cell[StyleData["TBI"],
  StyleMenuListing->None,
  FontFamily->"Times",
  FontWeight->"Bold",
  FontSlant->"Italic"],

Cell[StyleData["MR"],
  StyleMenuListing->None,
  FontFamily->"Courier",
  FontWeight->"Plain",
  FontSlant->"Plain"],

Cell[StyleData["MO"],
  StyleMenuListing->None,
  FontFamily->"Courier",
  FontWeight->"Plain",
  FontSlant->"Italic"],

Cell[StyleData["MB"],
  StyleMenuListing->None,
  FontFamily->"Courier",
  FontWeight->"Bold",
  FontSlant->"Plain"],

Cell[StyleData["MBO"],
  StyleMenuListing->None,
  FontFamily->"Courier",
  FontWeight->"Bold",
  FontSlant->"Italic"],

Cell[StyleData["SR"],
  StyleMenuListing->None,
  FontFamily->"Helvetica",
  FontWeight->"Plain",
  FontSlant->"Plain"],

Cell[StyleData["SO"],
  StyleMenuListing->None,
  FontFamily->"Helvetica",
  FontWeight->"Plain",
  FontSlant->"Italic"],

Cell[StyleData["SB"],
  StyleMenuListing->None,
  FontFamily->"Helvetica",
  FontWeight->"Bold",
  FontSlant->"Plain"],

Cell[StyleData["SBO"],
  StyleMenuListing->None,
  FontFamily->"Helvetica",
  FontWeight->"Bold",
  FontSlant->"Italic"],

Cell[CellGroupData[{

Cell[StyleData["SO10"],
  StyleMenuListing->None,
  FontFamily->"Helvetica",
  FontSize->10,
  FontWeight->"Plain",
  FontSlant->"Italic"],

Cell[StyleData["SO10", "Printout"],
  StyleMenuListing->None,
  FontFamily->"Helvetica",
  FontSize->7,
  FontWeight->"Plain",
  FontSlant->"Italic"],

Cell[StyleData["SO10", "EnhancedPrintout"],
  StyleMenuListing->None,
  FontFamily->"Futura",
  FontSize->7,
  FontWeight->"Plain",
  FontSlant->"Italic"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Miscellaneous Styles", "Section"],

Cell[CellGroupData[{

Cell[StyleData["PictureCaption"],
  CellMargins->{{47, 4}, {0, 2}},
  PageBreakAbove->False,
  StyleMenuListing->None,
  FontFamily->"Helvetica",
  FontSize->9],

Cell[StyleData["PictureCaption", "Printout"],
  CellMargins->{{39, 4}, {2, 4}},
  FontSize->7],

Cell[StyleData["PictureCaption", "EnhancedPrintout"],
  CellMargins->{{39, 4}, {2, 4}},
  FontFamily->"Futura",
  FontSize->7],

Cell[StyleData["PictureCaption", "EnhancedPrintoutNonGray"],
  CellMargins->{{39, 4}, {2, 4}},
  FontFamily->"Futura",
  FontSize->7]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["MathCaption"],
  CellDingbat->"\[FilledSmallSquare]",
  CellMargins->{{46, 42}, {0, 14}},
  PageBreakBelow->False,
  LineSpacing->{1, 1},
  ParagraphSpacing->{0, 8},
  FontColor->RGBColor[0, 0, 0.6]],

Cell[StyleData["MathCaption", "Printout"],
  CellMargins->{{42, 42}, {0, 14}},
  FontSize->9,
  FontColor->GrayLevel[0]],

Cell[StyleData["MathCaption", "EnhancedPrintout"],
  CellMargins->{{42, 42}, {0, 14}},
  FontFamily->"Palatino",
  FontSize->9,
  FontColor->GrayLevel[0]],

Cell[StyleData["MathCaption", "EnhancedPrintoutNonGray"],
  CellMargins->{{42, 42}, {0, 14}},
  FontFamily->"Palatino",
  FontSize->9,
  FontColor->GrayLevel[0]]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Commentary"],
  CellFrame->{{2, 0}, {0, 0}},
  CellMargins->{{36, 10}, {7, 7}},
  PageBreakBelow->False,
  CellFrameMargins->8,
  CellFrameColor->RGBColor[0, 0.2, 1],
  LineSpacing->{1, 3},
  ParagraphSpacing->{0, 8},
  FontSlant->"Italic"],

Cell[StyleData["Commentary", "Printout"],
  CellMargins->{{36, 0}, {6, 6}},
  CellFrameColor->GrayLevel[0.8],
  FontSize->10],

Cell[StyleData["Commentary", "EnhancedPrintout"],
  CellMargins->{{36, 0}, {6, 6}},
  CellFrameColor->GrayLevel[0.8],
  FontFamily->"Palatino",
  FontSize->10],

Cell[StyleData["Commentary", "EnhancedPrintoutNonGray"],
  CellMargins->{{36, 0}, {6, 6}},
  CellFrameColor->GrayLevel[0.8],
  FontFamily->"Palatino",
  FontSize->10]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["ItemizedText"],
  CellMargins->{{20, 4}, {0, 4}},
  LineSpacing->{1, 3},
  ParagraphSpacing->{0, 4},
  ParagraphIndent->-21,
  CounterIncrements->"ItemizedText"],

Cell[StyleData["ItemizedText", "Printout"],
  ParagraphIndent->-18,
  FontSize->11],

Cell[StyleData["ItemizedText", "EnhancedPrintout"],
  ParagraphIndent->-18,
  FontFamily->"Palatino",
  FontSize->10],

Cell[StyleData["ItemizedText", "EnhancedPrintoutNonGray"],
  ParagraphIndent->-18,
  FontFamily->"Palatino",
  FontSize->10]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["ItemizedTextNote"],
  CellMargins->{{41, 4}, {0, 4}},
  LineSpacing->{1, 3},
  ParagraphSpacing->{0, 4},
  CounterIncrements->"Text"],

Cell[StyleData["ItemizedTextNote", "Printout"],
  CellMargins->{{38, 4}, {0, 4}},
  FontSize->11],

Cell[StyleData["ItemizedTextNote", "EnhancedPrintout"],
  CellMargins->{{38, 4}, {0, 4}},
  FontFamily->"Palatino",
  FontSize->10],

Cell[StyleData["ItemizedTextNote", "EnhancedPrintoutNonGray"],
  CellMargins->{{38, 4}, {0, 4}},
  FontFamily->"Palatino",
  FontSize->10]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["BulletText"],
  CellMargins->{{20, 4}, {0, 4}},
  LineSpacing->{1, 3},
  ParagraphSpacing->{0, 4},
  ParagraphIndent->-21],

Cell[StyleData["BulletText", "Printout"],
  ParagraphIndent->-18,
  FontSize->11],

Cell[StyleData["BulletText", "EnhancedPrintout"],
  ParagraphIndent->-18,
  FontFamily->"Palatino",
  FontSize->10],

Cell[StyleData["BulletText", "EnhancedPrintoutNonGray"],
  ParagraphIndent->-18,
  FontFamily->"Palatino",
  FontSize->10]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["IndentedText"],
  CellMargins->{{20, 4}, {0, 6}},
  LineSpacing->{1, 3},
  ParagraphSpacing->{0, 8},
  CounterIncrements->"Text"],

Cell[StyleData["IndentedText", "Printout"],
  FontSize->10],

Cell[StyleData["IndentedText", "EnhancedPrintout"],
  FontFamily->"Palatino",
  FontSize->10],

Cell[StyleData["IndentedText", "EnhancedPrintoutNonGray"],
  FontFamily->"Palatino",
  FontSize->10]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["HiddenSection"],
  CellFrame->{{0, 0}, {0.5, 0}},
  CellMargins->{{10, Inherited}, {8, 30}},
  CellGroupingRules->{"SectionGrouping", 30},
  PageBreakBelow->False,
  CellFrameMargins->8,
  LineSpacing->{1, 7},
  CounterIncrements->"Section",
  CounterAssignments->{{"Subsection", 0}, {"Subsubsection", 0}},
  FontFamily->"Helvetica",
  FontSize->20,
  FontWeight->"Bold",
  CellTags->"Section"],

Cell[StyleData["HiddenSection", "Printout"],
  CellFrame->False,
  CellMargins->{{2, 0}, {7, 124}},
  CellFrameColor->GrayLevel[0],
  FontSize->16,
  FontColor->GrayLevel[1]],

Cell[StyleData["HiddenSection", "EnhancedPrintout"],
  CellFrame->False,
  CellMargins->{{2, 0}, {7, 124}},
  CellFrameColor->GrayLevel[0],
  FontFamily->"Futura",
  FontSize->16,
  FontColor->GrayLevel[1]],

Cell[StyleData["HiddenSection", "EnhancedPrintoutNonGray"],
  CellFrame->False,
  CellMargins->{{2, 0}, {7, 124}},
  CellFrameColor->GrayLevel[0],
  FontFamily->"Futura",
  FontSize->16,
  FontColor->GrayLevel[1]]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["CompactText"],
  CellMargins->{{10, 4}, {0, 8}},
  ConversionRules:>{"HTML" -> {"<FONT SIZE=\"-1\">", "</FONT>\n"}},
  ParagraphSpacing->{0, 0},
  StyleMenuListing->None,
  FontSize->10],

Cell[StyleData["CompactText", "Printout"],
  CellMargins->{{2, 0}, {0, 8}},
  FontSize->8],

Cell[StyleData["CompactText", "EnhancedPrintout"],
  CellMargins->{{2, 0}, {0, 8}},
  TextJustification->1,
  FontFamily->"Palatino",
  FontSize->8],

Cell[StyleData["CompactText", "EnhancedPrintoutNonGray"],
  CellMargins->{{2, 0}, {0, 8}},
  TextJustification->1,
  FontFamily->"Palatino",
  FontSize->8]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Emphasis Boxes and Pictures", "Section"],

Cell[CellGroupData[{

Cell[StyleData["DefinitionBox"],
  CellFrame->0.5,
  CellMargins->{{10, 4}, {0, 8}},
  CellHorizontalScrolling->True,
  PageBreakWithin->False,
  AutoIndent->False,
  AutoSpacing->False,
  ShowStringCharacters->True,
  LineIndent->0,
  StyleMenuListing->None,
  FontWeight->"Plain",
  Background->RGBColor[1, 0.6, 0.6],
  GridBoxOptions->{RowSpacings->1.5,
  ColumnSpacings->1,
  ColumnWidths->{0.3, 0.7},
  ColumnAlignments->{Left}}],

Cell[StyleData["DefinitionBox", "Printout"],
  CellMargins->{{2, 0}, {0, 8}},
  FontSize->10,
  Background->GrayLevel[0.900008]],

Cell[StyleData["DefinitionBox", "EnhancedPrintout"],
  CellMargins->{{2, 4}, {0, 8}},
  FontFamily->"Palatino",
  FontSize->10,
  Background->GrayLevel[0.900008]],

Cell[StyleData["DefinitionBox", "EnhancedPrintoutNonGray"],
  CellMargins->{{2, 4}, {0, 8}},
  FontFamily->"Palatino",
  FontSize->10,
  Background->GrayLevel[0.999954]]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["DefinitionBox3Col"],
  CellFrame->0.5,
  CellMargins->{{10, 4}, {0, 8}},
  CellHorizontalScrolling->True,
  PageBreakWithin->False,
  AutoIndent->False,
  AutoSpacing->False,
  ShowStringCharacters->True,
  LineIndent->0,
  StyleMenuListing->None,
  FontWeight->"Plain",
  Background->RGBColor[1, 0.6, 0.6],
  GridBoxOptions->{RowSpacings->1.5,
  ColumnSpacings->1,
  ColumnWidths->{0.2, 0.3, 0.5},
  ColumnAlignments->{Left}}],

Cell[StyleData["DefinitionBox3Col", "Printout"],
  CellMargins->{{2, 4}, {0, 8}},
  FontSize->10,
  Background->GrayLevel[0.900008]],

Cell[StyleData["DefinitionBox3Col", "EnhancedPrintout"],
  CellMargins->{{2, 4}, {0, 8}},
  FontFamily->"Palatino",
  FontSize->10,
  Background->GrayLevel[0.900008]],

Cell[StyleData["DefinitionBox3Col", "EnhancedPrintoutNonGray"],
  CellMargins->{{2, 4}, {0, 8}},
  FontFamily->"Palatino",
  FontSize->10,
  Background->GrayLevel[0.999954]]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["DefinitionBox4Col"],
  CellFrame->0.5,
  CellMargins->{{10, 4}, {0, 8}},
  CellHorizontalScrolling->True,
  PageBreakWithin->False,
  AutoIndent->False,
  AutoSpacing->False,
  ShowStringCharacters->True,
  LineIndent->0,
  StyleMenuListing->None,
  FontWeight->"Plain",
  Background->RGBColor[1, 0.6, 0.6],
  GridBoxOptions->{RowSpacings->1.5,
  ColumnSpacings->1,
  ColumnWidths->{0.15, 0.35, 0.15, 0.35},
  ColumnAlignments->{Left}}],

Cell[StyleData["DefinitionBox4Col", "Printout"],
  CellMargins->{{2, 4}, {0, 8}},
  FontSize->10,
  Background->GrayLevel[0.900008]],

Cell[StyleData["DefinitionBox4Col", "EnhancedPrintout"],
  CellMargins->{{2, 4}, {0, 8}},
  FontFamily->"Palatino",
  FontSize->10,
  Background->GrayLevel[0.900008]],

Cell[StyleData["DefinitionBox4Col", "EnhancedPrintoutNonGray"],
  CellMargins->{{2, 4}, {0, 8}},
  FontFamily->"Palatino",
  FontSize->10,
  Background->GrayLevel[0.999954]]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["DefinitionBox5Col"],
  CellFrame->0.5,
  CellMargins->{{10, 4}, {0, 8}},
  CellHorizontalScrolling->True,
  PageBreakWithin->False,
  AutoIndent->False,
  AutoSpacing->False,
  ShowStringCharacters->True,
  LineIndent->0,
  StyleMenuListing->None,
  FontWeight->"Plain",
  Background->RGBColor[1, 0.6, 0.6],
  GridBoxOptions->{RowSpacings->1.5,
  ColumnSpacings->1,
  ColumnWidths->0.2,
  ColumnAlignments->{Left}}],

Cell[StyleData["DefinitionBox5Col", "Printout"],
  CellMargins->{{2, 4}, {0, 8}},
  FontSize->10,
  Background->GrayLevel[0.900008]],

Cell[StyleData["DefinitionBox5Col", "EnhancedPrintout"],
  CellMargins->{{2, 4}, {0, 8}},
  FontFamily->"Palatino",
  FontSize->10,
  Background->GrayLevel[0.900008]],

Cell[StyleData["DefinitionBox5Col", "EnhancedPrintoutNonGray"],
  CellMargins->{{2, 4}, {0, 8}},
  FontFamily->"Palatino",
  FontSize->10,
  Background->GrayLevel[0.999954]]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["DefinitionBox6Col"],
  CellFrame->0.5,
  CellMargins->{{10, 4}, {0, 8}},
  CellHorizontalScrolling->True,
  PageBreakWithin->False,
  AutoIndent->False,
  AutoSpacing->False,
  ShowStringCharacters->True,
  LineIndent->0,
  StyleMenuListing->None,
  FontWeight->"Plain",
  Background->RGBColor[1, 0.6, 0.6],
  GridBoxOptions->{RowSpacings->1.5,
  ColumnSpacings->1,
  ColumnWidths->{0.13, 0.24, 0.13, 0.13, 0.24, 0.13},
  ColumnAlignments->{Left}}],

Cell[StyleData["DefinitionBox6Col", "Printout"],
  CellMargins->{{2, 4}, {0, 8}},
  FontSize->10,
  Background->GrayLevel[0.900008]],

Cell[StyleData["DefinitionBox6Col", "EnhancedPrintout"],
  CellMargins->{{2, 4}, {0, 8}},
  FontFamily->"Palatino",
  FontSize->10,
  Background->GrayLevel[0.900008]],

Cell[StyleData["DefinitionBox6Col", "EnhancedPrintoutNonGray"],
  CellMargins->{{2, 4}, {0, 8}},
  FontFamily->"Palatino",
  FontSize->10,
  Background->GrayLevel[0.999954]]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["TopBox"],
  CellFrame->{{0.5, 0.5}, {0, 0.5}},
  CellMargins->{{11, 4}, {0, 8}},
  CellHorizontalScrolling->True,
  PageBreakBelow->False,
  AutoIndent->False,
  AutoSpacing->False,
  ShowStringCharacters->True,
  LineIndent->0,
  StyleMenuListing->None,
  FontWeight->"Plain",
  Background->RGBColor[1, 0.6, 0.6],
  GridBoxOptions->{RowSpacings->1.5,
  ColumnSpacings->1,
  ColumnWidths->{0.31, 0.62},
  ColumnAlignments->{Left}}],

Cell[StyleData["TopBox", "Printout"],
  CellMargins->{{2, 0}, {-2, 8}},
  FontSize->10,
  Background->GrayLevel[0.900008]],

Cell[StyleData["TopBox", "EnhancedPrintout"],
  CellMargins->{{2, 0}, {-4, 8}},
  FontFamily->"Palatino",
  FontSize->10,
  Background->GrayLevel[0.900008]],

Cell[StyleData["TopBox", "EnhancedPrintoutNonGray"],
  CellMargins->{{2, 0}, {-4, 8}},
  FontFamily->"Palatino",
  FontSize->10,
  Background->GrayLevel[0.999954]]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["MiddleBox"],
  CellFrame->{{0.5, 0.5}, {0, 0}},
  CellMargins->{{11, 4}, {0, -7}},
  CellHorizontalScrolling->True,
  PageBreakAbove->False,
  PageBreakBelow->False,
  CellFrameMargins->{{8, 8}, {4, 4}},
  AutoIndent->False,
  AutoSpacing->False,
  ShowStringCharacters->True,
  LineIndent->0,
  StyleMenuListing->None,
  FontWeight->"Plain",
  Background->RGBColor[1, 0.6, 0.6],
  GridBoxOptions->{RowSpacings->1.5,
  ColumnSpacings->1,
  ColumnWidths->{0.31, 0.62},
  ColumnAlignments->{Left}}],

Cell[StyleData["MiddleBox", "Printout"],
  CellMargins->{{2, 0}, {-1, 0}},
  CellFrameMargins->{{8, 8}, {4, 1}},
  FontSize->10,
  Background->GrayLevel[0.900008]],

Cell[StyleData["MiddleBox", "EnhancedPrintout"],
  CellMargins->{{2, 0}, {-1, 1}},
  CellFrameMargins->{{8, 8}, {4, 1}},
  FontFamily->"Palatino",
  FontSize->10,
  Background->GrayLevel[0.900008]],

Cell[StyleData["MiddleBox", "EnhancedPrintoutNonGray"],
  CellMargins->{{2, 0}, {-1, 1}},
  CellFrameMargins->{{8, 8}, {4, 1}},
  FontFamily->"Palatino",
  FontSize->10,
  Background->GrayLevel[0.999954]]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["MiddleSpacedBox"],
  CellFrame->{{0.5, 0.5}, {0, 0}},
  CellMargins->{{11, 4}, {-3, -8}},
  CellHorizontalScrolling->True,
  PageBreakAbove->False,
  PageBreakBelow->False,
  AutoIndent->False,
  AutoSpacing->False,
  ShowStringCharacters->True,
  LineIndent->0,
  StyleMenuListing->None,
  FontWeight->"Plain",
  Background->RGBColor[1, 0.6, 0.6],
  GridBoxOptions->{RowSpacings->1.5,
  ColumnSpacings->1,
  ColumnWidths->{0.31, 0.62},
  ColumnAlignments->{Left},
  RowMinHeight->1.2}],

Cell[StyleData["MiddleSpacedBox", "Printout"],
  CellMargins->{{2, 0}, {-5, 0}},
  CellFrameMargins->{{8, 8}, {6, 2}},
  FontSize->10,
  Background->GrayLevel[0.900008],
  GridBoxOptions->{RowMinHeight->1.8}],

Cell[StyleData["MiddleSpacedBox", "EnhancedPrintout"],
  CellMargins->{{2, 0}, {-7, 0}},
  CellFrameMargins->{{8, 8}, {6, 2}},
  FontFamily->"Palatino",
  FontSize->10,
  Background->GrayLevel[0.900008],
  GridBoxOptions->{RowMinHeight->1.8}],

Cell[StyleData["MiddleSpacedBox", "EnhancedPrintoutNonGray"],
  CellMargins->{{2, 0}, {-7, 0}},
  CellFrameMargins->{{8, 8}, {6, 2}},
  FontFamily->"Palatino",
  FontSize->10,
  Background->GrayLevel[0.999954],
  GridBoxOptions->{RowMinHeight->1.8}]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["MiddleSpanBox"],
  CellFrame->{{0.5, 0.5}, {0, 0}},
  CellMargins->{{11, 4}, {-3, -8}},
  CellHorizontalScrolling->True,
  PageBreakAbove->False,
  PageBreakBelow->False,
  AutoIndent->False,
  AutoSpacing->False,
  ShowStringCharacters->True,
  LineIndent->0,
  StyleMenuListing->None,
  FontWeight->"Plain",
  Background->RGBColor[1, 0.6, 0.6],
  GridBoxOptions->{RowSpacings->1.5,
  ColumnSpacings->1,
  ColumnWidths->{0.9, 0.03},
  ColumnAlignments->{Left},
  RowMinHeight->1.2}],

Cell[StyleData["MiddleSpanBox", "Printout"],
  CellMargins->{{2, 0}, {-5, 0}},
  CellFrameMargins->{{8, 8}, {6, 2}},
  FontSize->10,
  Background->GrayLevel[0.900008],
  GridBoxOptions->{RowMinHeight->1.8}],

Cell[StyleData["MiddleSpanBox", "EnhancedPrintout"],
  CellMargins->{{2, 0}, {-7, 0}},
  CellFrameMargins->{{8, 8}, {6, 2}},
  FontFamily->"Palatino",
  FontSize->10,
  Background->GrayLevel[0.900008],
  GridBoxOptions->{RowMinHeight->1.8}],

Cell[StyleData["MiddleSpanBox", "EnhancedPrintoutNonGray"],
  CellMargins->{{2, 0}, {-7, 0}},
  CellFrameMargins->{{8, 8}, {6, 2}},
  FontFamily->"Palatino",
  FontSize->10,
  Background->GrayLevel[0.999954],
  GridBoxOptions->{RowMinHeight->1.8}]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["BottomBox"],
  CellFrame->{{0.5, 0.5}, {0.5, 0}},
  CellMargins->{{11, 4}, {0, -7}},
  CellHorizontalScrolling->True,
  PageBreakAbove->False,
  PageBreakBelow->False,
  AutoIndent->False,
  AutoSpacing->False,
  ShowStringCharacters->True,
  LineIndent->0,
  StyleMenuListing->None,
  FontWeight->"Plain",
  Background->RGBColor[1, 0.6, 0.6],
  GridBoxOptions->{RowSpacings->1.5,
  ColumnSpacings->1,
  ColumnWidths->{0.31, 0.62},
  ColumnAlignments->{Left},
  RowMinHeight->1.2}],

Cell[StyleData["BottomBox", "Printout"],
  CellMargins->{{2, 0}, {-1, -2}},
  CellFrameMargins->{{8, 8}, {4, -2}},
  FontSize->10,
  Background->GrayLevel[0.900008],
  GridBoxOptions->{RowMinHeight->2.2}],

Cell[StyleData["BottomBox", "EnhancedPrintout"],
  CellMargins->{{2, 0}, {-1, -2}},
  CellFrameMargins->{{8, 8}, {4, -2}},
  FontFamily->"Palatino",
  FontSize->10,
  Background->GrayLevel[0.900008],
  GridBoxOptions->{RowMinHeight->2.2}],

Cell[StyleData["BottomBox", "EnhancedPrintoutNonGray"],
  CellMargins->{{2, 0}, {-1, -2}},
  CellFrameMargins->{{8, 8}, {4, -2}},
  FontFamily->"Palatino",
  FontSize->10,
  Background->GrayLevel[0.999954],
  GridBoxOptions->{RowMinHeight->2.2}]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["TopSpanBox"],
  CellFrame->{{0.5, 0.5}, {0, 0.5}},
  CellMargins->{{11, 4}, {-2, 8}},
  CellHorizontalScrolling->True,
  PageBreakBelow->False,
  AutoIndent->False,
  AutoSpacing->False,
  ShowStringCharacters->True,
  LineIndent->0,
  StyleMenuListing->None,
  FontWeight->"Plain",
  Background->RGBColor[1, 0.6, 0.6],
  GridBoxOptions->{RowSpacings->1.5,
  ColumnSpacings->1,
  ColumnWidths->{0.9, 0.03},
  ColumnAlignments->{Left}}],

Cell[StyleData["TopSpanBox", "Printout"],
  CellMargins->{{2, 0}, {-2, 8}},
  FontSize->10,
  Background->GrayLevel[0.900008]],

Cell[StyleData["TopSpanBox", "EnhancedPrintout"],
  CellMargins->{{2, 0}, {-4, 8}},
  FontFamily->"Palatino",
  FontSize->10,
  Background->GrayLevel[0.900008]],

Cell[StyleData["TopSpanBox", "EnhancedPrintoutNonGray"],
  CellMargins->{{2, 0}, {-4, 8}},
  FontFamily->"Palatino",
  FontSize->10,
  Background->GrayLevel[0.999954]]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Picture"],
  CellMargins->{{12, Inherited}, {0, 8}},
  CellHorizontalScrolling->True],

Cell[StyleData["Picture", "Printout"],
  CellMargins->{{2, Inherited}, {0, 8}}],

Cell[StyleData["Picture", "EnhancedPrintout"],
  CellMargins->{{2, Inherited}, {0, 8}}],

Cell[StyleData["Picture", "EnhancedPrintoutNonGray"],
  CellMargins->{{2, Inherited}, {0, 8}}]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Caption"],
  CellMargins->{{12, 4}, {0, 2}},
  PageBreakAbove->False,
  FontFamily->"Helvetica",
  FontSize->9],

Cell[StyleData["Caption", "Printout"],
  CellMargins->{{2, 4}, {2, 4}},
  FontSize->7],

Cell[StyleData["Caption", "EnhancedPrintout"],
  CellMargins->{{2, 4}, {2, 4}},
  FontFamily->"Futura",
  FontSize->7],

Cell[StyleData["Caption", "EnhancedPrintoutNonGray"],
  CellMargins->{{2, 4}, {2, 4}},
  FontFamily->"Futura",
  FontSize->7]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Tables", "Section"],

Cell[CellGroupData[{

Cell[StyleData["SingleRowTable"],
  CellMargins->{{10, 4}, {0, 8}},
  CellHorizontalScrolling->True,
  PageBreakWithin->False,
  AutoIndent->False,
  AutoSpacing->False,
  ShowStringCharacters->True,
  LineIndent->0,
  StyleMenuListing->None,
  GridBoxOptions->{RowSpacings->1.5,
  ColumnSpacings->2,
  ColumnAlignments->{Left}}],

Cell[StyleData["SingleRowTable", "Printout"],
  CellMargins->{{2, 0}, {0, 8}},
  FontSize->10],

Cell[StyleData["SingleRowTable", "EnhancedPrintout"],
  CellMargins->{{2, 0}, {0, 8}},
  FontSize->10],

Cell[StyleData["SingleRowTable", "EnhancedPrintoutNonGray"],
  CellMargins->{{2, 0}, {0, 8}},
  FontSize->10]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["2ColumnTable"],
  CellMargins->{{10, 4}, {0, 8}},
  CellHorizontalScrolling->True,
  PageBreakWithin->False,
  AutoIndent->False,
  AutoSpacing->False,
  ShowStringCharacters->True,
  LineIndent->0,
  StyleMenuListing->None,
  GridBoxOptions->{RowSpacings->1.5,
  ColumnSpacings->2,
  ColumnWidths->{0.34, 0.64},
  ColumnAlignments->{Left, Center}}],

Cell[StyleData["2ColumnTable", "Printout"],
  CellMargins->{{2, 0}, {0, 8}},
  FontSize->10],

Cell[StyleData["2ColumnTable", "EnhancedPrintout"],
  CellMargins->{{2, 0}, {0, 8}},
  FontSize->10],

Cell[StyleData["2ColumnTable", "EnhancedPrintoutNonGray"],
  CellMargins->{{2, 0}, {0, 8}},
  FontSize->10]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["2ColumnEvenTable"],
  CellMargins->{{10, 4}, {0, 8}},
  CellHorizontalScrolling->True,
  PageBreakWithin->False,
  AutoIndent->False,
  AutoSpacing->False,
  ShowStringCharacters->True,
  LineIndent->0,
  StyleMenuListing->None,
  GridBoxOptions->{RowSpacings->1.5,
  ColumnSpacings->2,
  ColumnWidths->0.49,
  ColumnAlignments->{Left, Center}}],

Cell[StyleData["2ColumnEvenTable", "Printout"],
  CellMargins->{{2, 0}, {0, 8}},
  FontSize->10],

Cell[StyleData["2ColumnEvenTable", "EnhancedPrintout"],
  CellMargins->{{2, 0}, {0, 8}},
  FontSize->10],

Cell[StyleData["2ColumnEvenTable", "EnhancedPrintoutNonGray"],
  CellMargins->{{2, 0}, {0, 8}},
  FontSize->10]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["3ColumnTable"],
  PageWidth->400,
  CellMargins->{{10, 10}, {1, 1}},
  CellHorizontalScrolling->True,
  ShowStringCharacters->True,
  CounterIncrements->"Table",
  StyleMenuListing->None,
  GridBoxOptions->{ColumnWidths->0.336,
  RowAlignments->Center,
  ColumnAlignments->{Left, Center},
  GridFrame->{{0, 0}, {0.5, 2}},
  RowLines->{True, False},
  ColumnLines->False,
  GridDefaultElement:>Cell[ "Your Data", "TableText"]}],

Cell[StyleData["3ColumnTable", "Printout"],
  CellMargins->{{2, 10}, {1, 1}},
  FontSize->10]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["3ColumnTablePlain"],
  PageWidth->400,
  CellMargins->{{12, 10}, {7, 7}},
  CellHorizontalScrolling->True,
  ShowStringCharacters->True,
  CounterIncrements->"Table",
  StyleMenuListing->None,
  GridBoxOptions->{ColumnWidths->0.336,
  RowAlignments->Center,
  ColumnAlignments->{Left, Center},
  GridFrame->{{0, 0}, {0.5, 2}},
  RowLines->{True, False},
  ColumnLines->False,
  GridDefaultElement:>Cell[ "Your Data", "TableText"]}],

Cell[StyleData["3ColumnTablePlain", "Printout"],
  CellMargins->{{2, 10}, {4, 4}},
  FontSize->10]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["4ColumnTable"],
  PageWidth->400,
  CellMargins->{{10, 10}, {1, 1}},
  CellHorizontalScrolling->True,
  ShowStringCharacters->True,
  CounterIncrements->"Table",
  StyleMenuListing->None,
  GridBoxOptions->{ColumnWidths->0.251,
  RowAlignments->Center,
  ColumnAlignments->{Left, Center},
  GridFrame->{{0, 0}, {0.5, 2}},
  RowLines->{True, False},
  ColumnLines->False,
  GridDefaultElement:>Cell[ "Your Data", "TableText"]}],

Cell[StyleData["4ColumnTable", "Printout"],
  CellMargins->{{2, 10}, {1, 1}},
  FontSize->10]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["4ColumnTablePlain"],
  PageWidth->400,
  CellMargins->{{12, 10}, {7, 7}},
  CellHorizontalScrolling->True,
  ShowStringCharacters->True,
  CounterIncrements->"Table",
  StyleMenuListing->None,
  GridBoxOptions->{ColumnWidths->0.251,
  RowAlignments->Center,
  ColumnAlignments->{Left, Center},
  GridFrame->{{0, 0}, {0.5, 2}},
  RowLines->{True, False},
  ColumnLines->False,
  GridDefaultElement:>Cell[ "Your Data", "TableText"]}],

Cell[StyleData["4ColumnTablePlain", "Printout"],
  CellMargins->{{2, 10}, {4, 4}},
  FontSize->10]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["5ColumnTable"],
  PageWidth->400,
  CellMargins->{{10, 10}, {1, 1}},
  CellHorizontalScrolling->True,
  ShowStringCharacters->True,
  CounterIncrements->"Table",
  StyleMenuListing->None,
  GridBoxOptions->{ColumnWidths->0.201,
  RowAlignments->Center,
  ColumnAlignments->{Left, Center},
  GridFrame->{{0, 0}, {0.5, 2}},
  RowLines->{True, False},
  ColumnLines->False,
  GridDefaultElement:>Cell[ "Your Data", "TableText"]}],

Cell[StyleData["5ColumnTable", "Printout"],
  CellMargins->{{2, 10}, {1, 1}},
  FontSize->10]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["5ColumnTablePlain"],
  PageWidth->400,
  CellMargins->{{12, 10}, {7, 7}},
  CellHorizontalScrolling->True,
  ShowStringCharacters->True,
  CounterIncrements->"Table",
  StyleMenuListing->None,
  GridBoxOptions->{ColumnWidths->0.201,
  RowAlignments->Center,
  ColumnAlignments->{Left, Center},
  GridFrame->{{0, 0}, {0.5, 2}},
  RowLines->{True, False},
  ColumnLines->False,
  GridDefaultElement:>Cell[ "Your Data", "TableText"]}],

Cell[StyleData["5ColumnTablePlain", "Printout"],
  CellMargins->{{2, 10}, {4, 4}},
  FontSize->10]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["6ColumnTable"],
  CellMargins->{{10, 4}, {0, 8}},
  CellHorizontalScrolling->True,
  PageBreakWithin->False,
  AutoIndent->False,
  AutoSpacing->False,
  ShowStringCharacters->True,
  LineIndent->0,
  StyleMenuListing->None,
  GridBoxOptions->{RowSpacings->1.5,
  ColumnSpacings->2,
  ColumnWidths->0.16,
  ColumnAlignments->{Left, Center}}],

Cell[StyleData["6ColumnTable", "Printout"],
  CellMargins->{{2, 0}, {0, 8}},
  FontSize->10],

Cell[StyleData["6ColumnTable", "EnhancedPrintout"],
  CellMargins->{{2, 0}, {0, 8}},
  FontSize->10],

Cell[StyleData["6ColumnTable", "EnhancedPrintoutNonGray"],
  CellMargins->{{2, 0}, {0, 8}},
  FontSize->10]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["7ColumnTable"],
  CellMargins->{{10, 4}, {0, 8}},
  CellHorizontalScrolling->True,
  PageBreakWithin->False,
  AutoIndent->False,
  AutoSpacing->False,
  ShowStringCharacters->True,
  LineIndent->0,
  StyleMenuListing->None,
  GridBoxOptions->{RowSpacings->1.5,
  ColumnSpacings->2,
  ColumnWidths->0.14,
  ColumnAlignments->{Left, Center}}],

Cell[StyleData["7ColumnTable", "Printout"],
  CellMargins->{{2, 0}, {0, 8}},
  FontSize->10],

Cell[StyleData["7ColumnTable", "EnhancedPrintout"],
  CellMargins->{{2, 0}, {0, 8}},
  FontSize->10],

Cell[StyleData["7ColumnTable", "EnhancedPrintoutNonGray"],
  CellMargins->{{2, 0}, {0, 8}},
  FontSize->10]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["8ColumnTable"],
  CellMargins->{{10, 4}, {0, 8}},
  CellHorizontalScrolling->True,
  PageBreakWithin->False,
  AutoIndent->False,
  AutoSpacing->False,
  ShowStringCharacters->True,
  LineIndent->0,
  StyleMenuListing->None,
  GridBoxOptions->{RowSpacings->1.5,
  ColumnSpacings->2,
  ColumnWidths->0.12,
  ColumnAlignments->{Left, Center}}],

Cell[StyleData["8ColumnTable", "Printout"],
  CellMargins->{{2, 0}, {0, 8}},
  FontSize->10],

Cell[StyleData["8ColumnTable", "EnhancedPrintout"],
  CellMargins->{{2, 0}, {0, 8}},
  FontSize->10],

Cell[StyleData["8ColumnTable", "EnhancedPrintoutNonGray"],
  CellMargins->{{2, 0}, {0, 8}},
  FontSize->10]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["TableHead"],
  PageWidth->400,
  CellMargins->{{12, 10}, {1, 7}},
  LineSpacing->{1, 2},
  CounterIncrements->"TableHead",
  StyleMenuListing->None,
  FontFamily->"Times",
  FontWeight->"Bold",
  GridBoxOptions->{ColumnWidths->40,
  ColumnAlignments->{Left}}],

Cell[StyleData["TableHead", "Printout"],
  FontSize->10]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Table"],
  PageWidth->400,
  CellMargins->{{10, 10}, {1, 1}},
  CellHorizontalScrolling->True,
  ShowStringCharacters->True,
  CounterIncrements->"Table",
  StyleMenuListing->None,
  GridBoxOptions->{ColumnWidths->0.503,
  RowAlignments->Center,
  ColumnAlignments->{Left, Center},
  GridFrame->{{0, 0}, {0.5, 2}},
  RowLines->{True, False},
  ColumnLines->False,
  GridDefaultElement:>Cell[ "Your Data", "TableText"]}],

Cell[StyleData["Table", "Printout"],
  CellMargins->{{2, 10}, {1, 1}},
  FontSize->10]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["TablePlain"],
  PageWidth->400,
  CellMargins->{{12, 10}, {7, 7}},
  CellHorizontalScrolling->True,
  ShowStringCharacters->True,
  CounterIncrements->"Table",
  StyleMenuListing->None,
  GridBoxOptions->{ColumnWidths->0.503,
  RowAlignments->Center,
  ColumnAlignments->{Left, Center},
  GridFrame->{{0, 0}, {0.5, 2}},
  RowLines->{True, False},
  ColumnLines->False,
  GridDefaultElement:>Cell[ "Your Data", "TableText"]}],

Cell[StyleData["TablePlain", "Printout"],
  CellMargins->{{2, 10}, {4, 4}},
  FontSize->10]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["TableNote"],
  PageWidth->400,
  CellMargins->{{12, 10}, {7, 1}},
  LineSpacing->{1, 1},
  ParagraphSpacing->{0.3, 0},
  FontFamily->"Times",
  FontSize->10],

Cell[StyleData["TableNote", "Printout"],
  FontSize->9]
}, Closed]],

Cell[CellGroupData[{

Cell["Inline Styles for Tables", "Subsection"],

Cell[CellGroupData[{

Cell[StyleData["TableHeadText"],
  CounterIncrements->"TableHead",
  FontFamily->"Times",
  FontWeight->"Plain"],

Cell[StyleData["TableHeadText", "Printout"],
  FontSize->10]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["ColumnHead"],
  CounterIncrements->"Table",
  FontFamily->"Times",
  FontSlant->"Italic"],

Cell[StyleData["ColumnHead", "Printout"],
  FontSize->10]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["TableText"],
  TextAlignment->Left,
  LineSpacing->{1, 1},
  FontFamily->"Times",
  FontSize->12],

Cell[StyleData["TableText", "Printout"],
  FontSize->10]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Styles for Automatic Numbering", "Section"],

Cell["\<\
The following styles are useful for numbered equations, figures, etc.  They \
automatically give the cell a FrameLabel containing a reference to a \
particular counter, and also increment that counter.\
\>", "Text"],

Cell[CellGroupData[{

Cell[StyleData["NumberedEquation"],
  CellMargins->{{45, 10}, {7, 7}},
  CellFrameLabels->{{None, Cell[ 
          TextData[ {"(", 
            CounterBox[ "Section"], ".", 
            CounterBox[ "NumberedEquation"], ")"}]]}, {None, None}},
  DefaultFormatType->DefaultTextFormatType,
  SpanMaxSize->Infinity,
  CounterIncrements->"NumberedEquation",
  FormatTypeAutoConvert->False],

Cell[StyleData["NumberedEquation", "Printout"],
  CellMargins->{{39, 55}, {0, 10}},
  FontSize->10],

Cell[StyleData["NumberedEquation", "EnhancedPrintout"],
  CellMargins->{{39, 55}, {0, 10}},
  FontFamily->"Palatino",
  FontSize->10],

Cell[StyleData["NumberedEquation", "EnhancedPrintoutNonGray"],
  CellMargins->{{39, 55}, {0, 10}},
  FontFamily->"Palatino",
  FontSize->10]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Formulas and Programming", "Section"],

Cell[CellGroupData[{

Cell[StyleData["DisplayFormula"],
  CellMargins->{{45, Inherited}, {7, 7}},
  CellHorizontalScrolling->True,
  ScriptLevel->0,
  SingleLetterItalics->True,
  SpanMaxSize->Infinity,
  UnderoverscriptBoxOptions->{LimitsPositioning->True}],

Cell[StyleData["DisplayFormula", "Printout"],
  FontSize->10],

Cell[StyleData["DisplayFormula", "EnhancedPrintout"],
  FontFamily->"Palatino",
  FontSize->10],

Cell[StyleData["DisplayFormula", "EnhancedPrintoutNonGray"],
  FontFamily->"Palatino",
  FontSize->10]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["DisplayMath"],
  CellMargins->{{45, 10}, {7, 7}},
  Evaluatable->False,
  CellGroupingRules->"InputGrouping",
  CellHorizontalScrolling->True,
  PageBreakWithin->False,
  GroupPageBreakWithin->False,
  DefaultFormatType->DefaultInputFormatType,
  AutoItalicWords->{},
  FormatType->InputForm,
  ShowStringCharacters->True,
  NumberMarks->True,
  CounterIncrements->"Input"],

Cell[StyleData["DisplayMath", "Printout"],
  CellMargins->{{39, 0}, {6, 6}},
  FontSize->9],

Cell[StyleData["DisplayMath", "EnhancedPrintout"],
  CellMargins->{{39, 0}, {4, 6}},
  FontFamily->"WRICourier",
  FontSize->9],

Cell[StyleData["DisplayMath", "EnhancedPrintoutNonGray"],
  CellMargins->{{39, 0}, {4, 6}},
  FontFamily->"WRICourier",
  FontSize->9]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["EquationNumber"],
  LineSpacing->{1.83, 0}],

Cell[StyleData["EquationNumber", "Printout"],
  LineSpacing->{1.7, 0},
  FontSize->10],

Cell[StyleData["EquationNumber", "EnhancedPrintout"],
  LineSpacing->{1.7, 0},
  FontFamily->"Palatino",
  FontSize->10],

Cell[StyleData["EquationNumber", "EnhancedPrintoutNonGray"],
  LineSpacing->{1.7, 0},
  FontFamily->"Palatino",
  FontSize->10]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Program"],
  CellFrame->{{0, 0}, {0.5, 0.5}},
  CellMargins->{{12, Inherited}, {7, 7}},
  CellFrameMargins->{{0, 0}, {7, 5}},
  FontFamily->"Courier"],

Cell[StyleData["Program", "Printout"],
  CellMargins->{{18, 30}, {Inherited, 4}},
  FontSize->9.5],

Cell[StyleData["Program", "EnhancedPrintout"],
  CellMargins->{{18, 30}, {Inherited, 4}},
  FontFamily->"WRICourier",
  FontSize->9.5],

Cell[StyleData["Program", "EnhancedPrintoutNonGray"],
  CellMargins->{{18, 30}, {Inherited, 4}},
  FontFamily->"WRICourier",
  FontSize->9.5]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Contents and Index", "Section"],

Cell[CellGroupData[{

Cell[StyleData["ContentsTitle"],
  CellMargins->{{21, 4}, {48, 72}},
  FontFamily->"Helvetica",
  FontSize->24,
  FontWeight->"Bold"],

Cell[StyleData["ContentsTitle", "Printout"],
  CellMargins->{{12, 0}, {48, 48}},
  PageBreakBelow->False,
  FontSize->20],

Cell[StyleData["ContentsTitle", "EnhancedPrintout"],
  CellMargins->{{12, 0}, {48, 48}},
  PageBreakBelow->False,
  FontFamily->"Futura",
  FontSize->20]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["ContentsSection"],
  ShowGroupOpenCloseIcon->True,
  CellMargins->{{35, 4}, {3, 18}},
  CellGroupingRules->{"SectionGrouping", 70},
  StyleMenuListing->None,
  FontFamily->"Helvetica",
  FontSize->12,
  FontWeight->"Bold"],

Cell[StyleData["ContentsSection", "Printout"],
  CellMargins->{{20, 0}, {3, 18}},
  PageBreakBelow->False,
  FontSize->11],

Cell[StyleData["ContentsSection", "EnhancedPrintout"],
  CellMargins->{{20, 0}, {3, 18}},
  PageBreakBelow->False,
  FontFamily->"Futura",
  FontSize->11],

Cell[StyleData["ContentsSection", "EnhancedPrintoutNonGray"],
  CellMargins->{{20, 0}, {3, 18}},
  PageBreakBelow->False,
  FontFamily->"Futura",
  FontSize->11]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["IndexSection"],
  CellDingbat->"\[FilledSquare]",
  CellMargins->{{20, 4}, {5, 20}},
  StyleMenuListing->None,
  FontFamily->"Helvetica",
  FontSize->12,
  FontWeight->"Bold"],

Cell[StyleData["IndexSection", "Printout"],
  CellMargins->{{12, 0}, {5, 20}},
  PageBreakBelow->False,
  FontSize->12]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Contents"],
  ShowGroupOpenCloseIcon->False,
  CellMargins->{{50, 4}, {0, 5}},
  CellGroupingRules->{"SectionGrouping", 90},
  StyleMenuListing->None],

Cell[StyleData["Contents", "Printout"],
  CellMargins->{{40, 4}, {0, 5}},
  FontSize->11],

Cell[StyleData["Contents", "EnhancedPrintout"],
  CellMargins->{{40, 5}, {0, 5}},
  FontFamily->"Palatino",
  FontSize->11],

Cell[StyleData["Contents", "EnhancedPrintoutNonGray"],
  CellMargins->{{40, 5}, {0, 5}},
  FontFamily->"Palatino",
  FontSize->11]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Index"],
  CellMargins->{{21, 4}, {0, 0}},
  ParagraphIndent->-48,
  StyleMenuListing->None],

Cell[StyleData["Index", "Printout"],
  CellMargins->{{13, 0}, {0, 0}},
  FontSize->10],

Cell[StyleData["Index", "EnhancedPrintout"],
  CellMargins->{{13, 0}, {0, 0}},
  FontFamily->"Palatino",
  FontSize->10],

Cell[StyleData["Index", "EnhancedPrintoutNonGray"],
  CellMargins->{{13, 0}, {0, 0}},
  FontFamily->"Palatino",
  FontSize->10]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["IndexSubentry"],
  CellMargins->{{36, 4}, {0, 0}},
  ParagraphIndent->-48,
  StyleMenuListing->None],

Cell[StyleData["IndexSubentry", "Printout"],
  CellMargins->{{24, 0}, {0, 0}},
  FontSize->10],

Cell[StyleData["IndexSubentry", "EnhancedPrintout"],
  CellMargins->{{24, 0}, {0, 0}},
  FontFamily->"Palatino",
  FontSize->10],

Cell[StyleData["IndexSubentry", "EnhancedPrintoutNonGray"],
  CellMargins->{{24, 0}, {0, 0}},
  FontFamily->"Palatino",
  FontSize->10]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Index2Column"],
  CellMargins->{{21, 4}, {0, 8}},
  ParagraphIndent->-20,
  TabSpacings->1,
  StyleMenuListing->None,
  GridBoxOptions->{ColumnWidths->0.5,
  ColumnAlignments->{Left}}],

Cell[StyleData["Index2Column", "Printout"],
  CellMargins->{{2, 2}, {6, 6}},
  TextJustification->1,
  FontSize->10],

Cell[StyleData["Index2Column", "EnhancedPrintout"],
  CellMargins->{{2, 2}, {6, 6}},
  TextJustification->1,
  FontFamily->"Palatino",
  FontSize->10],

Cell[StyleData["Index2Column", "EnhancedPrintoutNonGray"],
  CellMargins->{{2, 2}, {6, 6}},
  TextJustification->1,
  FontFamily->"Palatino",
  FontSize->10]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Leader"],
  StyleMenuListing->None,
  FontFamily->"Times",
  FontSize->12,
  FontWeight->"Plain"],

Cell[StyleData["Leader", "Printout"],
  FontSize->10],

Cell[StyleData["Leader", "EnhancedPrintout"],
  FontFamily->"Palatino",
  FontSize->10]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["PageLink"],
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic,
  FontFamily->"Times",
  FontSize->12,
  FontWeight->"Plain",
  FontSlant->"Plain",
  FontColor->RGBColor[0, 0, 1],
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`NotebookLocate[ #2]}]&),
  Active->True,
  ButtonFrame->"None"}],

Cell[StyleData["PageLink", "Printout"],
  FontSize->10,
  FontColor->GrayLevel[0]],

Cell[StyleData["PageLink", "EnhancedPrintout"],
  FontSize->10,
  FontColor->GrayLevel[0]]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["TOCPage"],
  CellSize->{22, Inherited},
  TextAlignment->Right,
  StyleMenuListing->None,
  FontFamily->"Times",
  FontSize->12,
  FontWeight->"Plain"],

Cell[StyleData["TOCPage", "Printout"],
  FontSize->10],

Cell[StyleData["TOCPage", "EnhancedPrintout"],
  FontFamily->"Palatino",
  FontSize->10]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["TOCTitle"],
  CellMargins->{{20, 0}, {1, 8}},
  CellGroupingRules->{"SectionGrouping", 70},
  TabSpacings->46,
  CounterIncrements->"TOCTitle",
  CounterAssignments->{{"TOCSection", 0}},
  FontFamily->"Helvetica",
  FontSize->12,
  FontWeight->"Bold"],

Cell[StyleData["TOCTitle", "Printout"],
  CellMargins->{{12, 0}, {1, 8}},
  PageBreakBelow->False,
  TabSpacings->47.4,
  FontSize->11],

Cell[StyleData["TOCTitle", "EnhancedPrintout"],
  CellMargins->{{12, 0}, {1, 8}},
  PageBreakBelow->False,
  TabSpacings->47.4,
  FontFamily->"Futura",
  FontSize->11]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["TOCSection"],
  CellMargins->{{48, 0}, {1, 1}},
  CellGroupingRules->{"SectionGrouping", 75},
  TabSpacings->42.9,
  CounterIncrements->"TOCSection",
  CounterAssignments->{{"TOCSubsection", 0}},
  FontFamily->"Helvetica",
  FontSize->12],

Cell[StyleData["TOCSection", "Printout"],
  CellMargins->{{36, 0}, {1, 1}},
  PageBreakBelow->False,
  TabSpacings->44.4,
  FontSize->11],

Cell[StyleData["TOCSection", "EnhancedPrintout"],
  CellMargins->{{36, 0}, {1, 1}},
  PageBreakBelow->False,
  TabSpacings->44.4,
  FontFamily->"Palatino",
  FontSize->11]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["TOCSubsection"],
  CellMargins->{{76, 0}, {1, 1}},
  CellGroupingRules->{"SectionGrouping", 80},
  TabSpacings->39.8,
  CounterIncrements->"TOCSubsection",
  CounterAssignments->{{"TOCSubsubsection", 0}},
  FontSize->12],

Cell[StyleData["TOCSubsection", "Printout"],
  CellMargins->{{72, 0}, {1, 1}},
  PageBreakBelow->False,
  FontSize->10],

Cell[StyleData["TOCSubsection", "EnhancedPrintout"],
  CellMargins->{{72, 0}, {1, 1}},
  PageBreakBelow->False,
  FontFamily->"Palatino",
  FontSize->10]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["TOCSubsubsection"],
  CellMargins->{{104, 0}, {1, 1}},
  CellGroupingRules->{"SectionGrouping", 85},
  TabSpacings->36.7,
  CounterIncrements->"TOCSubsubsection",
  FontSize->12],

Cell[StyleData["TOCSubsubsection", "Printout"],
  CellMargins->{{96, 0}, {1, 1}},
  PageBreakBelow->False,
  FontSize->9],

Cell[StyleData["TOCSubsubsection", "EnhancedPrintout"],
  CellMargins->{{96, 0}, {1, 1}},
  PageBreakBelow->False,
  FontFamily->"Palatino",
  FontSize->9]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["TOCTitleCondensed"],
  CellMargins->{{20, 0}, {1, 8}},
  CellGroupingRules->{"SectionGrouping", 70},
  TabSpacings->50.4,
  CounterIncrements->"TOCTitleCondensed",
  CounterAssignments->{{"TOCSectionCondensed", 0}, {
      "TOCSubsectionCondensed", 0}},
  FontFamily->"Helvetica",
  FontSize->12,
  FontWeight->"Bold"],

Cell[StyleData["TOCTitleCondensed", "Printout"],
  CellMargins->{{12, 0}, {1, 8}},
  PageBreakBelow->False,
  FontSize->11],

Cell[StyleData["TOCTitleCondensed", "EnhancedPrintout"],
  CellMargins->{{12, 0}, {1, 8}},
  PageBreakBelow->False,
  FontFamily->"Futura",
  FontSize->11]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["TOCSectionCondensed"],
  CellMargins->{{48, 0}, {1, 1}},
  CellGroupingRules->{"SectionGrouping", 75},
  TabSpacings->47.4,
  CounterIncrements->"TOCSectionCondensed",
  CounterAssignments->{{"TOCSubsection", 0}},
  FontFamily->"Helvetica",
  FontSize->10,
  FontWeight->"Bold",
  FontColor->GrayLevel[0.2]],

Cell[StyleData["TOCSectionCondensed", "Printout"],
  CellMargins->{{36, 0}, {1, 1}},
  PageBreakBelow->False,
  FontSize->11],

Cell[StyleData["TOCSectionCondensed", "EnhancedPrintout"],
  CellMargins->{{36, 0}, {1, 1}},
  PageBreakBelow->False,
  FontFamily->"Palatino",
  FontSize->11]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["TOCSubsectionCondensed"],
  PageWidth->470,
  CellMargins->{{76, 0}, {1, 1}},
  CellGroupingRules->{"SectionGrouping", 80},
  TextJustification->1,
  FontSize->12],

Cell[StyleData["TOCSubsectionCondensed", "Printout"],
  CellMargins->{{72, 0}, {1, 1}},
  PageBreakBelow->False,
  FontSize->10],

Cell[StyleData["TOCSubsectionCondensed", "EnhancedPrintout"],
  CellMargins->{{72, 0}, {1, 1}},
  PageBreakBelow->False,
  FontFamily->"Palatino",
  FontSize->10]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["TOCSubsubsectionCondensed"],
  CellMargins->{{104, 0}, {1, 1}},
  CellGroupingRules->{"SectionGrouping", 85},
  TabSpacings->39.3,
  CounterIncrements->"TOCSubsubsectionCondensed",
  FontSize->12],

Cell[StyleData["TOCSubsubsectionCondensed", "Printout"],
  CellMargins->{{96, 0}, {1, 1}},
  PageBreakBelow->False,
  FontSize->9],

Cell[StyleData["TOCSubsubsectionCondensed", "EnhancedPrintout"],
  CellMargins->{{96, 0}, {1, 1}},
  PageBreakBelow->False,
  FontFamily->"Palatino",
  FontSize->9]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Function List", "Section"],

Cell[CellGroupData[{

Cell[StyleData["FunctionName"],
  CellDingbat->"\[FilledSquare]",
  CellMargins->{{24, 10}, {10, 12}},
  CellGroupingRules->{"SectionGrouping", 40},
  PageBreakBelow->False,
  FontFamily->"Courier",
  FontSize->14,
  FontWeight->"Bold",
  CellTags->"FunctionName"],

Cell[StyleData["FunctionName", "Printout"],
  CellMargins->{{9, 0}, {10, 10}},
  FontSize->12],

Cell[StyleData["FunctionName", "EnhancedPrintout"],
  CellMargins->{{9, 0}, {10, 10}},
  FontFamily->"Courier",
  FontSize->12],

Cell[StyleData["FunctionName", "EnhancedPrintoutNonGray"],
  CellMargins->{{9, 0}, {10, 10}},
  FontFamily->"Courier",
  FontSize->12]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["SubsectionIcon"],
  ShowGroupOpenCloseIcon->True,
  CellMargins->{{24, 10}, {0, 30}},
  CellGroupingRules->{"SectionGrouping", 50},
  PageBreakBelow->False,
  FontSize->14,
  FontWeight->"Bold",
  CellTags->"FunctionSection"],

Cell[StyleData["SubsectionIcon", "Printout"],
  CellMargins->{{20, 0}, {0, 20}},
  FontSize->13],

Cell[StyleData["SubsectionIcon", "EnhancedPrintout"],
  CellMargins->{{20, 0}, {0, 20}},
  FontFamily->"Palatino",
  FontSize->10],

Cell[StyleData["SubsectionIcon", "EnhancedPrintoutNonGray"],
  CellMargins->{{20, 0}, {0, 20}},
  FontFamily->"Palatino",
  FontSize->10]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["FunctionSubsection"],
  CellDingbat->"\[FilledSquare]",
  CellMargins->{{36, 10}, {0, 6}},
  CellGroupingRules->{"SectionGrouping", 60},
  PageBreakBelow->False,
  FontWeight->"Bold",
  CellTags->"FunctionSubsection"],

Cell[StyleData["FunctionSubsection", "Printout"],
  CellMargins->{{30, 0}, {0, 6}}],

Cell[StyleData["FunctionSubsection", "EnhancedPrintout"],
  CellMargins->{{30, 0}, {0, 6}},
  FontFamily->"Palatino",
  FontSize->11],

Cell[StyleData["FunctionSubsection", "EnhancedPrintoutNonGray"],
  CellMargins->{{30, 0}, {0, 6}},
  FontFamily->"Palatino",
  FontSize->11]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["SubsubsectionIcon"],
  ShowGroupOpenCloseIcon->True,
  CellMargins->{{36, 10}, {0, 6}},
  CellGroupingRules->{"SectionGrouping", 60},
  PageBreakBelow->False,
  FontWeight->"Bold",
  CellTags->"SubsubsectionIcon"],

Cell[StyleData["SubsubsectionIcon", "Printout"],
  CellMargins->{{30, 0}, {0, 6}},
  FontSize->11],

Cell[StyleData["SubsubsectionIcon", "EnhancedPrintout"],
  CellMargins->{{30, 0}, {0, 6}},
  FontFamily->"Palatino",
  FontSize->9],

Cell[StyleData["SubsubsectionIcon", "EnhancedPrintoutNonGray"],
  CellMargins->{{30, 0}, {0, 6}},
  FontFamily->"Palatino",
  FontSize->9]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["FunctionDescription"],
  CellMargins->{{36, 10}, {4, 0}},
  LineSpacing->{1, 3},
  ParagraphSpacing->{0.7, 0},
  CounterIncrements->"Text",
  FontWeight->"Plain"],

Cell[StyleData["FunctionDescription", "Printout"],
  CellMargins->{{30, 0}, {4, 0}},
  FontSize->11],

Cell[StyleData["FunctionDescription", "EnhancedPrintout"],
  CellMargins->{{30, 0}, {4, 0}},
  TextJustification->0,
  FontFamily->"Palatino",
  FontSize->10],

Cell[StyleData["FunctionDescription", "EnhancedPrintoutNonGray"],
  CellMargins->{{30, 0}, {4, 0}},
  TextJustification->0,
  FontFamily->"Palatino",
  FontSize->10]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["FunctionDescriptionRuled"],
  CellFrame->{{0, 0}, {0.25, 0.25}},
  CellMargins->{{36, 10}, {4, 0}},
  LineSpacing->{1, 3},
  ParagraphSpacing->{0.7, 0},
  CounterIncrements->"Text"],

Cell[StyleData["FunctionDescriptionRuled", "Printout"],
  CellMargins->{{30, 0}, {4, 0}},
  FontSize->11],

Cell[StyleData["FunctionDescriptionRuled", "EnhancedPrintout"],
  CellMargins->{{30, 0}, {4, 0}},
  TextJustification->0,
  FontFamily->"Palatino",
  FontSize->10],

Cell[StyleData["FunctionDescriptionRuled", "EnhancedPrintoutNonGray"],
  CellMargins->{{30, 0}, {4, 0}},
  TextJustification->0,
  FontFamily->"Palatino",
  FontSize->10]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["FunctionDescriptionRuleTop"],
  CellFrame->{{0, 0}, {0, 0.25}},
  CellMargins->{{36, 10}, {4, 0}},
  LineSpacing->{1, 3},
  ParagraphSpacing->{0.7, 0},
  CounterIncrements->"Text"],

Cell[StyleData["FunctionDescriptionRuleTop", "Printout"],
  CellMargins->{{30, 0}, {4, 0}},
  FontSize->11],

Cell[StyleData["FunctionDescriptionRuleTop", "EnhancedPrintout"],
  CellMargins->{{30, 0}, {4, 0}},
  TextJustification->0,
  FontFamily->"Palatino",
  FontSize->10],

Cell[StyleData["FunctionDescriptionRuleTop", "EnhancedPrintoutNonGray"],
  CellMargins->{{30, 0}, {4, 0}},
  TextJustification->0,
  FontFamily->"Palatino",
  FontSize->10]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["FunctionDescriptionRuleBottom"],
  CellFrame->{{0, 0}, {0.25, 0}},
  CellMargins->{{36, 10}, {4, 0}},
  LineSpacing->{1, 3},
  ParagraphSpacing->{0.7, 0},
  CounterIncrements->"Text"],

Cell[StyleData["FunctionDescriptionRuleBottom", "Printout"],
  CellMargins->{{30, 0}, {4, 0}},
  FontSize->11],

Cell[StyleData["FunctionDescriptionRuleBottom", "EnhancedPrintout"],
  CellMargins->{{30, 0}, {4, 0}},
  TextJustification->0,
  FontFamily->"Palatino",
  FontSize->10],

Cell[StyleData["FunctionDescriptionRuleBottom", "EnhancedPrintoutNonGray"],
  CellMargins->{{30, 0}, {4, 0}},
  TextJustification->0,
  FontFamily->"Palatino",
  FontSize->10]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["FunctionExample"],
  CellMargins->{{36, 10}, {4, 0}},
  StyleMenuListing->None,
  FontSize->10],

Cell[StyleData["FunctionExample", "Printout"],
  CellMargins->{{30, 0}, {4, 0}},
  FontSize->9],

Cell[StyleData["FunctionExample", "EnhancedPrintout"],
  CellMargins->{{30, 0}, {4, 0}},
  FontFamily->"Palatino",
  FontSize->9],

Cell[StyleData["FunctionExample", "EnhancedPrintoutNonGray"],
  CellMargins->{{30, 0}, {4, 0}},
  FontFamily->"Palatino",
  FontSize->9]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["FunctionTextNote"],
  CellMargins->{{36, 4}, {0, 4}},
  LineSpacing->{1, 3},
  ParagraphSpacing->{0, 4},
  LineIndent->0],

Cell[StyleData["FunctionTextNote", "Printout"],
  CellMargins->{{36, 4}, {0, 4}},
  FontSize->9],

Cell[StyleData["FunctionTextNote", "EnhancedPrintout"],
  CellMargins->{{36, 4}, {0, 4}},
  FontFamily->"Palatino",
  FontSize->8],

Cell[StyleData["FunctionTextNote", "EnhancedPrintoutNonGray"],
  CellMargins->{{36, 4}, {0, 4}},
  FontFamily->"Palatino",
  FontSize->8]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["3ColumnFunctionTable"],
  CellMargins->{{36, 4}, {0, 8}},
  CellHorizontalScrolling->True,
  PageBreakWithin->False,
  AutoIndent->False,
  AutoSpacing->False,
  LineIndent->0,
  GridBoxOptions->{RowSpacings->1.5,
  ColumnSpacings->2,
  ColumnWidths->{0.28, 0.28, 0.43},
  ColumnAlignments->{Left}}],

Cell[StyleData["3ColumnFunctionTable", "Printout"],
  CellMargins->{{30, 0}, {0, 8}},
  FontSize->10],

Cell[StyleData["3ColumnFunctionTable", "EnhancedPrintout"],
  CellMargins->{{30, 0}, {0, 8}},
  FontSize->10],

Cell[StyleData["3ColumnFunctionTable", "EnhancedPrintoutNonGray"],
  CellMargins->{{30, 0}, {0, 8}},
  FontSize->10]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Browser Emulation", "Section"],

Cell[CellGroupData[{

Cell[StyleData["TextNormal"],
  CellMargins->{{12, 10}, {7, 7}},
  LineSpacing->{1, 3},
  CounterIncrements->"Text",
  FontFamily->"Times",
  FontSize->12],

Cell[StyleData["TextNormal", "Printout"],
  CellMargins->{{2, 2}, {6, 6}},
  FontSize->10]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["BrowserEmulation"],
  CellMargins->{{12, 1}, {7, 24}},
  CellGroupingRules->{"SectionGrouping", 70},
  LineSpacing->{1, 3},
  FontFamily->"Helvetica",
  GridBoxOptions->{ColumnWidths->0.25,
  ColumnAlignments->{Left},
  GridFrame->True,
  GridFrameMargins->0.5,
  ColumnLines->True}],

Cell[StyleData["Text", "Printout"],
  CellMargins->{{2, 2}, {6, 6}},
  FontSize->10]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["CategoryDefs"],
  CellMargins->{{300, 10}, {7, 7}},
  LineSpacing->{1, 3},
  FontFamily->"Helvetica",
  Background->RGBColor[1, 0.8, 0.6],
  GridBoxOptions->{ColumnAlignments->{Left},
  GridFrame->False,
  RowLines->True,
  ColumnLines->True}],

Cell[StyleData["Text", "Printout"],
  CellMargins->{{2, 2}, {6, 6}},
  FontSize->10]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Category1"],
  ShowCellBracket->False,
  ShowGroupOpenCloseIcon->True,
  CellMargins->{{12, 10}, {7, 7}},
  CellGroupingRules->{"SectionGrouping", 50},
  FontSize->16,
  FontWeight->"Bold"],

Cell[StyleData["Category1", "Printout"],
  CellMargins->{{2, 2}, {6, 6}}]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Category2"],
  ShowCellBracket->False,
  ShowGroupOpenCloseIcon->True,
  CellMargins->{{85, 10}, {7, 7}},
  CellGroupingRules->{"SectionGrouping", 60},
  FontSize->14,
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 0.500008]],

Cell[StyleData["Category2", "Printout"],
  CellMargins->{{2, 2}, {6, 6}}]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Category3"],
  ShowCellBracket->False,
  ShowGroupOpenCloseIcon->True,
  CellMargins->{{157, 10}, {7, 7}},
  CellGroupingRules->{"SectionGrouping", 70},
  FontSize->12,
  FontWeight->"Bold",
  FontColor->RGBColor[0.2, 0, 0.4]],

Cell[StyleData["Category3", "Printout"],
  CellMargins->{{2, 2}, {6, 6}}]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Category4"],
  ShowCellBracket->False,
  ShowGroupOpenCloseIcon->True,
  CellMargins->{{230, 10}, {7, 7}},
  CellGroupingRules->{"SectionGrouping", 80},
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0.300008, 0.4]],

Cell[StyleData["Category4", "Printout"],
  CellMargins->{{2, 2}, {6, 6}}]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Styles for Headers and Footers", "Section"],

Cell[CellGroupData[{

Cell[StyleData["Header"],
  CellMargins->{{0, 0}, {4, 1}},
  StyleMenuListing->None,
  FontFamily->"Helvetica",
  FontSize->8,
  FontWeight->"Bold"],

Cell[StyleData["Header", "Printout"]],

Cell[StyleData["Header", "EnhancedPrintout"],
  FontFamily->"Futura"],

Cell[StyleData["Header", "EnhancedPrintoutNonGray"],
  FontFamily->"Futura"]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Footer"],
  CellMargins->{{0, 0}, {0, 4}},
  StyleMenuListing->None,
  FontFamily->"Helvetica",
  FontSize->7,
  FontSlant->"Plain"],

Cell[StyleData["Footer", "Printout"]],

Cell[StyleData["Footer", "EnhancedPrintout"],
  FontFamily->"Futura"],

Cell[StyleData["Footer", "EnhancedPrintoutNonGray"],
  FontFamily->"Futura"]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["PageNumber"],
  CellMargins->{{0, 0}, {4, 1}},
  StyleMenuListing->None,
  FontFamily->"Helvetica",
  FontSize->8,
  FontWeight->"Bold"],

Cell[StyleData["PageNumber", "Printout"]],

Cell[StyleData["PageNumber", "EnhancedPrintout"],
  FontFamily->"Futura"],

Cell[StyleData["PageNumber", "EnhancedPrintoutNonGray"],
  FontFamily->"Futura"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Hyperlink Styles", "Section"],

Cell["\<\
The cells below define styles useful for making hypertext ButtonBoxes.  The \
\"Hyperlink\" style is for links within the same Notebook, or between \
Notebooks.\
\>", "Text"],

Cell[CellGroupData[{

Cell[StyleData["Hyperlink"],
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic,
  FontColor->RGBColor[0, 0, 1],
  FontVariations->{"Underline"->True},
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`NotebookLocate[ #2]}]&),
  Active->True,
  ButtonNote->ButtonData}],

Cell[StyleData["Hyperlink", "Printout"],
  FontSize->11,
  FontColor->GrayLevel[0],
  FontVariations->{"Underline"->False}],

Cell[StyleData["Hyperlink", "EnhancedPrintout"],
  FontFamily->"Palatino",
  FontSize->10,
  FontColor->GrayLevel[0],
  FontVariations->{"Underline"->False}],

Cell[StyleData["Hyperlink", "EnhancedPrintoutNonGray"],
  FontFamily->"Palatino",
  FontSize->10,
  FontColor->GrayLevel[0],
  FontVariations->{"Underline"->False}]
}, Closed]],

Cell["\<\
The following styles are for linking automatically to the on-line help \
system.\
\>", "Text"],

Cell[CellGroupData[{

Cell[StyleData["MainBookLink"],
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic,
  FontColor->RGBColor[0, 0, 1],
  FontVariations->{"Underline"->True},
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`HelpBrowserLookup[ "MainBook", #]}]&),
  Active->True,
  ButtonFrame->"None"}],

Cell[StyleData["MainBookLink", "Printout"],
  FontSize->11,
  FontColor->GrayLevel[0],
  FontVariations->{"Underline"->False}],

Cell[StyleData["MainBookLink", "EnhancedPrintout"],
  FontFamily->"Palatino",
  FontSize->10,
  FontColor->GrayLevel[0],
  FontVariations->{"Underline"->False}],

Cell[StyleData["MainBookLink", "EnhancedPrintoutNonGray"],
  FontFamily->"Palatino",
  FontSize->10,
  FontColor->GrayLevel[0],
  FontVariations->{"Underline"->False}]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["MainBookLinkMR"],
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic,
  FontFamily->"Courier",
  FontColor->RGBColor[0, 0, 1],
  FontVariations->{"Underline"->True},
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`HelpBrowserLookup[ "MainBook", #]}]&),
  Active->True,
  ButtonFrame->"None"}],

Cell[StyleData["MainBookLinkMR", "Printout"],
  FontSize->10,
  FontColor->GrayLevel[0],
  FontVariations->{"Underline"->False}],

Cell[StyleData["MainBookLinkMR", "EnhancedPrintout"],
  FontSize->10,
  FontColor->GrayLevel[0],
  FontVariations->{"Underline"->False}],

Cell[StyleData["MainBookLinkMR", "EnhancedPrintoutNonGray"],
  FontSize->10,
  FontColor->GrayLevel[0],
  FontVariations->{"Underline"->False}]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["AddOnsLink"],
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic,
  FontFamily->"Courier",
  FontColor->RGBColor[0, 0, 1],
  FontVariations->{"Underline"->True},
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`HelpBrowserLookup[ "AddOns", #]}]&),
  Active->True,
  ButtonFrame->"None"}],

Cell[StyleData["AddOnsLink", "Printout"],
  FontSize->11,
  FontColor->GrayLevel[0],
  FontVariations->{"Underline"->False}],

Cell[StyleData["AddOnsLink", "EnhancedPrintout"],
  FontSize->11,
  FontColor->GrayLevel[0],
  FontVariations->{"Underline"->False}],

Cell[StyleData["AddOnsLink", "EnhancedPrintoutNonGray"],
  FontSize->11,
  FontColor->GrayLevel[0],
  FontVariations->{"Underline"->False}]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["AddOnsLinkText"],
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic,
  FontFamily->"Times",
  FontColor->RGBColor[0, 0, 1],
  FontVariations->{"Underline"->True},
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`HelpBrowserLookup[ "AddOns", #]}]&),
  Active->True,
  ButtonFrame->"None"}],

Cell[StyleData["AddOnsLinkText", "Printout"],
  FontSize->11,
  FontColor->GrayLevel[0],
  FontVariations->{"Underline"->False}],

Cell[StyleData["AddOnsLinkText", "EnhancedPrintout"],
  FontSize->11,
  FontColor->GrayLevel[0],
  FontVariations->{"Underline"->False}],

Cell[StyleData["AddOnsLinkText", "EnhancedPrintoutNonGray"],
  FontSize->11,
  FontColor->GrayLevel[0],
  FontVariations->{"Underline"->False}]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["RefGuideLink"],
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic,
  FontFamily->"Courier",
  FontColor->RGBColor[0, 0, 1],
  FontVariations->{"Underline"->True},
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`HelpBrowserLookup[ "RefGuide", #]}]&),
  Active->True,
  ButtonFrame->"None"}],

Cell[StyleData["RefGuideLink", "Printout"],
  FontSize->10,
  FontColor->GrayLevel[0],
  FontVariations->{"Underline"->False}],

Cell[StyleData["RefGuideLink", "EnhancedPrintout"],
  FontFamily->"WRICourier",
  FontSize->10,
  FontColor->GrayLevel[0],
  FontVariations->{"Underline"->False}],

Cell[StyleData["RefGuideLink", "EnhancedPrintoutNonGray"],
  FontFamily->"WRICourier",
  FontSize->10,
  FontColor->GrayLevel[0],
  FontVariations->{"Underline"->False}]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["GettingStartedLink"],
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic,
  FontColor->RGBColor[0, 0, 1],
  FontVariations->{"Underline"->True},
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`HelpBrowserLookup[ "GettingStarted", #]}]&),
  Active->True,
  ButtonFrame->"None"}],

Cell[StyleData["GettingStartedLink", "Printout"],
  FontSize->11,
  FontColor->GrayLevel[0],
  FontVariations->{"Underline"->False}],

Cell[StyleData["GettingStartedLink", "EnhancedPrintout"],
  FontFamily->"Palatino",
  FontSize->10,
  FontColor->GrayLevel[0],
  FontVariations->{"Underline"->False}],

Cell[StyleData["GettingStartedLink", "EnhancedPrintoutNonGray"],
  FontFamily->"Palatino",
  FontSize->10,
  FontColor->GrayLevel[0],
  FontVariations->{"Underline"->False}]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["OtherInformationLink"],
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic,
  FontColor->RGBColor[0, 0, 1],
  FontVariations->{"Underline"->True},
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`HelpBrowserLookup[ "OtherInformation", #]}]&),
  Active->True,
  ButtonFrame->"None"}],

Cell[StyleData["OtherInformationLink", "Printout"],
  FontSize->11,
  FontColor->GrayLevel[0],
  FontVariations->{"Underline"->False}],

Cell[StyleData["OtherInformationLink", "EnhancedPrintout"],
  FontFamily->"Palatino",
  FontSize->10,
  FontColor->GrayLevel[0],
  FontVariations->{"Underline"->False}],

Cell[StyleData["OtherInformationLink", "EnhancedPrintoutNonGray"],
  FontFamily->"Palatino",
  FontSize->10,
  FontColor->GrayLevel[0],
  FontVariations->{"Underline"->False}]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Outline Styles", "Section"],

Cell[CellGroupData[{

Cell[StyleData["Outline1"],
  CellMargins->{{12, 10}, {7, 7}},
  CellGroupingRules->{"SectionGrouping", 50},
  ParagraphIndent->-38,
  CounterIncrements->"Outline1",
  FontSize->18,
  FontWeight->"Bold",
  CounterBoxOptions->{CounterFunction:>CapitalRomanNumeral}],

Cell[StyleData["Outline1", "Printout"],
  CounterBoxOptions->{CounterFunction:>CapitalRomanNumeral}]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Outline2"],
  CellMargins->{{59, 10}, {7, 7}},
  CellGroupingRules->{"SectionGrouping", 60},
  ParagraphIndent->-27,
  CounterIncrements->"Outline2",
  FontSize->15,
  FontWeight->"Bold",
  CounterBoxOptions->{CounterFunction:>(Part[ 
      CharacterRange[ "A", "Z"], #]&)}],

Cell[StyleData["Outline2", "Printout"],
  CounterBoxOptions->{CounterFunction:>(Part[ 
      CharacterRange[ "A", "Z"], #]&)}]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Outline3"],
  CellMargins->{{108, 10}, {7, 7}},
  CellGroupingRules->{"SectionGrouping", 70},
  ParagraphIndent->-21,
  CounterIncrements->"Outline3",
  FontSize->12,
  CounterBoxOptions->{CounterFunction:>Identity}],

Cell[StyleData["Outline3", "Printout"],
  CounterBoxOptions->{CounterFunction:>Identity}]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Outline4"],
  CellMargins->{{158, 10}, {7, 7}},
  CellGroupingRules->{"SectionGrouping", 80},
  ParagraphIndent->-18,
  CounterIncrements->"Outline4",
  FontSize->10,
  CounterBoxOptions->{CounterFunction:>(Part[ 
      CharacterRange[ "a", "z"], #]&)}],

Cell[StyleData["Outline4", "Printout"]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["AuthorTools", "Section"],

Cell[CellGroupData[{

Cell[StyleData["BilateralCell"],
  CellMargins->{{10, 4}, {0, 8}},
  StyleMenuListing->None,
  FontSize->12,
  GridBoxOptions->{ColumnWidths->{0.33, 0.6},
  RowAlignments->Top,
  ColumnAlignments->{Left}}],

Cell[StyleData["BilateralCell", "SlideShow"],
  CellMargins->{{36, 24}, {4, 4}},
  Background->GrayLevel[0.900008]],

Cell[StyleData["BilateralCell", "Printout"],
  CellMargins->{{2, 2}, {6, 6}},
  TextJustification->1,
  FontSize->10],

Cell[StyleData["BilateralCell", "EnhancedPrintout"],
  CellMargins->{{2, 2}, {6, 6}},
  TextJustification->1,
  FontFamily->"Palatino",
  FontSize->10],

Cell[StyleData["BilateralCell", "EnhancedPrintoutNonGray"],
  CellMargins->{{2, 2}, {6, 6}},
  TextJustification->1,
  FontFamily->"Palatino",
  FontSize->10]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["RuledPageBreak"],
  CellFrame->{{0, 0}, {0.25, 0}},
  CellMargins->{{10, 4}, {12, 0}},
  CellFrameMargins->{{0, 0}, {1, 0}},
  FontSize->8],

Cell[StyleData["RuledPageBreak", "SlideShow"],
  CellMargins->{{36, 24}, {4, 4}}],

Cell[StyleData["RuledPageBreak", "Printout"],
  CellMargins->{{2, 2}, {6, 6}},
  PageBreakBelow->True,
  FontSize->1],

Cell[StyleData["RuledPageBreak", "EnhancedPrintout"],
  CellMargins->{{2, 2}, {6, 6}},
  PageBreakBelow->True],

Cell[StyleData["RuledPageBreak", "EnhancedPrintoutNonGray"],
  CellMargins->{{2, 2}, {6, 6}},
  PageBreakBelow->True]
}, Closed]],

Cell[StyleData["PaletteHeadingButton"],
  StyleMenuListing->None,
  ButtonStyleMenuListing->None,
  FontFamily->"Helvetica",
  FontSize->12,
  FontWeight->"Bold",
  FontColor->GrayLevel[1],
  ButtonBoxOptions->{ButtonEvaluator->None,
  ButtonStyle->"Paste",
  ButtonMargins->6,
  Background->GrayLevel[0]}],

Cell[StyleData["PaletteButton"],
  StyleMenuListing->None,
  ButtonStyleMenuListing->None,
  FontFamily->"Helvetica",
  FontSize->12,
  FontWeight->"Bold",
  FontColor->GrayLevel[1],
  ButtonBoxOptions->{ButtonEvaluator->"Local",
  ButtonMargins->6,
  Background->RGBColor[0.100008, 0.100008, 0.4]}],

Cell[StyleData["PaletteButton2"],
  StyleMenuListing->None,
  ButtonStyleMenuListing->None,
  FontFamily->"Helvetica",
  FontSize->12,
  FontWeight->"Bold",
  FontColor->GrayLevel[1],
  ButtonBoxOptions->{ButtonEvaluator->"Local",
  ButtonMargins->4,
  Background->RGBColor[0.100008, 0.4, 0.6]}]
}, Closed]]
}, Open  ]]
},
FrontEndVersion->"4.1 for Macintosh",
ScreenRectangle->{{0, 1152}, {0, 848}},
WindowToolbars->{},
WindowSize->{500, 400},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
StyleDefinitions -> "Default.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "Section"->{
    Cell[6220, 221, 404, 12, 70, 26, 0, "StyleData", "Section", "All",
      CounterIncrements->"Section",
      CounterAssignments->{{"Subsection", 0}, {"Subsubsection", 0}},
      CellTags->"Section"],
    Cell[22279, 895, 410, 12, 56, 32, 0, "StyleData", "HiddenSection", "All",
      CounterIncrements->"Section",
      CounterAssignments->{{"Subsection", 0}, {"Subsubsection", 0}},
      CellTags->"Section"]},
  "Subsection"->{
    Cell[7005, 252, 349, 10, 70, 29, 0, "StyleData", "Subsection", "All",
      CounterIncrements->"Subsection",
      CounterAssignments->{{"Subsubsection", 0}},
      CellTags->"Subsection"]},
  "Subsubsection"->{
    Cell[7744, 281, 262, 7, 70, 32, 0, "StyleData", "Subsubsection", "All",
      CounterIncrements->"Subsubsection",
      CellTags->"Subsubsection"]},
  "FunctionName"->{
    Cell[60004, 2419, 264, 8, 70, 31, 0, "StyleData", "FunctionName", "All",
      CellTags->"FunctionName"]},
  "FunctionSection"->{
    Cell[60669, 2446, 241, 7, 70, 33, 0, "StyleData", "SubsectionIcon", 
    "All",
      CellTags->"FunctionSection"]},
  "FunctionSubsection"->{
    Cell[61319, 2472, 233, 6, 70, 37, 0, "StyleData", "FunctionSubsection", 
    "All",
      CellTags->"FunctionSubsection"]},
  "SubsubsectionIcon"->{
    Cell[61954, 2496, 229, 6, 70, 36, 0, "StyleData", "SubsubsectionIcon", 
    "All",
      CellTags->"SubsubsectionIcon"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"Section", 82388, 3300},
  {"Subsection", 82822, 3309},
  {"Subsubsection", 83038, 3314},
  {"FunctionName", 83211, 3318},
  {"FunctionSection", 83345, 3321},
  {"FunctionSubsection", 83492, 3325},
  {"SubsubsectionIcon", 83645, 3329}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1727, 52, 37, 0, 65, "Subtitle"],
Cell[1767, 54, 193, 4, 50, "Text"],

Cell[CellGroupData[{
Cell[1985, 62, 42, 0, 56, "Section"],
Cell[2030, 64, 166, 4, 70, 31, 0, "StyleData", "All", "Working"],
Cell[2199, 70, 106, 3, 70, 35, 0, "StyleData", "All", "AllBrackets"],
Cell[2308, 75, 140, 4, 70, 36, 0, "StyleData", "All", "Presentation"],
Cell[2451, 81, 212, 5, 70, 32, 0, "StyleData", "All", "Printout"],
Cell[2666, 88, 220, 5, 70, 40, 0, "StyleData", "All", "EnhancedPrintout"],
Cell[2889, 95, 227, 5, 70, 47, 0, "StyleData", "All", \
"EnhancedPrintoutNonGray"]
}, Closed]],

Cell[CellGroupData[{
Cell[3153, 105, 35, 0, 36, "Section"],
Cell[3191, 107, 99, 2, 70, "Text"],
Cell[3293, 111, 610, 16, 70, 27, 0, "StyleData", "Notebook", "All",
  StyleMenuListing->None]
}, Closed]],

Cell[CellGroupData[{
Cell[3940, 132, 38, 0, 36, "Section"],

Cell[CellGroupData[{
Cell[4003, 136, 395, 11, 70, 24, 0, "StyleData", "Title", "All",
  CounterIncrements->"Title",
  CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
      "Subtitle", 0}, {"Subsubtitle", 0}}],
Cell[4401, 149, 88, 2, 70, 36, 0, "StyleData", "Title", "Printout"],
Cell[4492, 153, 120, 3, 70, 44, 0, "StyleData", "Title", "EnhancedPrintout"],
Cell[4615, 158, 127, 3, 70, 51, 0, "StyleData", "Title", \
"EnhancedPrintoutNonGray"]
}, Closed]],

Cell[CellGroupData[{
Cell[4779, 166, 338, 9, 70, 27, 0, "StyleData", "Subtitle", "All",
  CounterIncrements->"Subtitle",
  CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
      "Subsubtitle", 0}}],
Cell[5120, 177, 91, 2, 70, 39, 0, "StyleData", "Subtitle", "Printout"],
Cell[5214, 181, 123, 3, 70, 47, 0, "StyleData", "Subtitle", \
"EnhancedPrintout"],
Cell[5340, 186, 130, 3, 70, 54, 0, "StyleData", "Subtitle", \
"EnhancedPrintoutNonGray"]
}, Closed]],

Cell[CellGroupData[{
Cell[5507, 194, 317, 8, 70, 30, 0, "StyleData", "Subsubtitle", "All",
  CounterIncrements->"Subsubtitle",
  CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}}],
Cell[5827, 204, 93, 2, 70, 42, 0, "StyleData", "Subsubtitle", "Printout"],
Cell[5923, 208, 125, 3, 70, 50, 0, "StyleData", "Subsubtitle", \
"EnhancedPrintout"],
Cell[6051, 213, 132, 3, 70, 57, 0, "StyleData", "Subsubtitle", \
"EnhancedPrintoutNonGray"]
}, Closed]],

Cell[CellGroupData[{
Cell[6220, 221, 404, 12, 70, 26, 0, "StyleData", "Section", "All",
  CounterIncrements->"Section",
  CounterAssignments->{{"Subsection", 0}, {"Subsubsection", 0}},
  CellTags->"Section"],
Cell[6627, 235, 88, 2, 70, 38, 0, "StyleData", "Section", "Printout"],
Cell[6718, 239, 120, 3, 70, 46, 0, "StyleData", "Section", \
"EnhancedPrintout"],
Cell[6841, 244, 127, 3, 70, 53, 0, "StyleData", "Section", \
"EnhancedPrintoutNonGray"]
}, Closed]],

Cell[CellGroupData[{
Cell[7005, 252, 349, 10, 70, 29, 0, "StyleData", "Subsection", "All",
  CounterIncrements->"Subsection",
  CounterAssignments->{{"Subsubsection", 0}},
  CellTags->"Subsection"],
Cell[7357, 264, 91, 2, 70, 41, 0, "StyleData", "Subsection", "Printout"],
Cell[7451, 268, 123, 3, 70, 49, 0, "StyleData", "Subsection", \
"EnhancedPrintout"],
Cell[7577, 273, 130, 3, 70, 56, 0, "StyleData", "Subsection", \
"EnhancedPrintoutNonGray"]
}, Closed]],

Cell[CellGroupData[{
Cell[7744, 281, 262, 7, 70, 32, 0, "StyleData", "Subsubsection", "All",
  CounterIncrements->"Subsubsection",
  CellTags->"Subsubsection"],
Cell[8009, 290, 94, 2, 70, 44, 0, "StyleData", "Subsubsection", "Printout"],
Cell[8106, 294, 126, 3, 70, 52, 0, "StyleData", "Subsubsection", \
"EnhancedPrintout"],
Cell[8235, 299, 133, 3, 70, 59, 0, "StyleData", "Subsubsection", \
"EnhancedPrintoutNonGray"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[8417, 308, 39, 0, 36, "Section"],

Cell[CellGroupData[{
Cell[8481, 312, 140, 4, 70, 23, 0, "StyleData", "Text", "All",
  CounterIncrements->"Text"],
Cell[8624, 318, 108, 3, 70, 35, 0, "StyleData", "Text", "Printout"],
Cell[8735, 323, 142, 4, 70, 43, 0, "StyleData", "Text", "EnhancedPrintout"],
Cell[8880, 329, 149, 4, 70, 50, 0, "StyleData", "Text", \
"EnhancedPrintoutNonGray"]
}, Closed]],

Cell[CellGroupData[{
Cell[9066, 338, 165, 5, 70, 28, 0, "StyleData", "SmallText", "All",
  CounterIncrements->"SmallText"],
Cell[9234, 345, 112, 3, 70, 40, 0, "StyleData", "SmallText", "Printout"],
Cell[9349, 350, 146, 4, 70, 48, 0, "StyleData", "SmallText", \
"EnhancedPrintout"],
Cell[9498, 356, 153, 4, 70, 55, 0, "StyleData", "SmallText", \
"EnhancedPrintoutNonGray"]
}, Closed]],

Cell[CellGroupData[{
Cell[9688, 365, 163, 5, 70, 32, 0, "StyleData", "CopyrightText", "All",
  StyleMenuListing->None],
Cell[9854, 372, 92, 2, 70, 44, 0, "StyleData", "CopyrightText", "Printout"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[9995, 380, 42, 0, 36, "Section"],
Cell[10040, 382, 246, 4, 70, "Text"],

Cell[CellGroupData[{
Cell[10311, 390, 429, 14, 70, 24, 0, "StyleData", "Input", "All",
  CounterIncrements->"Input"],
Cell[10743, 406, 111, 3, 70, 36, 0, "StyleData", "Input", "Printout"],
Cell[10857, 411, 119, 3, 70, 44, 0, "StyleData", "Input", \
"EnhancedPrintout"],
Cell[10979, 416, 126, 3, 70, 51, 0, "StyleData", "Input", \
"EnhancedPrintoutNonGray"]
}, Closed]],

Cell[CellGroupData[{
Cell[11142, 424, 416, 13, 70, 25, 0, "StyleData", "Output", "All",
  CounterIncrements->"Output"],
Cell[11561, 439, 112, 3, 70, 37, 0, "StyleData", "Output", "Printout"],
Cell[11676, 444, 120, 3, 70, 45, 0, "StyleData", "Output", \
"EnhancedPrintout"],
Cell[11799, 449, 127, 3, 70, 52, 0, "StyleData", "Output", \
"EnhancedPrintoutNonGray"]
}, Closed]],

Cell[CellGroupData[{
Cell[11963, 457, 549, 16, 70, 26, 0, "StyleData", "Message", "All",
  CounterIncrements->"Message",
  StyleMenuListing->None],
Cell[12515, 475, 164, 4, 70, 38, 0, "StyleData", "Message", "Printout"],
Cell[12682, 481, 197, 5, 70, 46, 0, "StyleData", "Message", \
"EnhancedPrintout"],
Cell[12882, 488, 204, 5, 70, 53, 0, "StyleData", "Message", \
"EnhancedPrintoutNonGray"]
}, Closed]],

Cell[CellGroupData[{
Cell[13123, 498, 523, 15, 70, 24, 0, "StyleData", "Print", "All",
  CounterIncrements->"Print",
  StyleMenuListing->None],
Cell[13649, 515, 135, 3, 70, 36, 0, "StyleData", "Print", "Printout"],
Cell[13787, 520, 168, 4, 70, 44, 0, "StyleData", "Print", \
"EnhancedPrintout"],
Cell[13958, 526, 175, 4, 70, 51, 0, "StyleData", "Print", \
"EnhancedPrintoutNonGray"]
}, Closed]],

Cell[CellGroupData[{
Cell[14170, 535, 414, 12, 70, 27, 0, "StyleData", "Graphics", "All",
  CounterIncrements->"Graphics",
  StyleMenuListing->None],
Cell[14587, 549, 163, 4, 70, 39, 0, "StyleData", "Graphics", "Printout"],
Cell[14753, 555, 196, 5, 70, 47, 0, "StyleData", "Graphics", \
"EnhancedPrintout"],
Cell[14952, 562, 203, 5, 70, 54, 0, "StyleData", "Graphics", \
"EnhancedPrintoutNonGray"]
}, Closed]],

Cell[CellGroupData[{
Cell[15192, 572, 128, 4, 70, 28, 0, "StyleData", "CellLabel", "All",
  StyleMenuListing->None],
Cell[15323, 578, 130, 4, 70, 40, 0, "StyleData", "CellLabel", "Printout"],
Cell[15456, 584, 138, 4, 70, 48, 0, "StyleData", "CellLabel", \
"EnhancedPrintout"],
Cell[15597, 590, 145, 4, 70, 55, 0, "StyleData", "CellLabel", \
"EnhancedPrintoutNonGray"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[15791, 600, 36, 0, 36, "Section"],
Cell[15830, 602, 121, 3, 30, "Text"],
Cell[15954, 607, 92, 3, 36, 21, 0, "StyleData", "RM", "All",
  StyleMenuListing->None],
Cell[16049, 612, 69, 2, 38, 21, 0, "StyleData", "BF", "All",
  StyleMenuListing->None],
Cell[16121, 616, 70, 2, 38, 21, 0, "StyleData", "IT", "All",
  StyleMenuListing->None],
Cell[16194, 620, 115, 4, 36, 21, 0, "StyleData", "TR", "All",
  StyleMenuListing->None],
Cell[16312, 626, 116, 4, 38, 21, 0, "StyleData", "TI", "All",
  StyleMenuListing->None],
Cell[16431, 632, 114, 4, 38, 21, 0, "StyleData", "TB", "All",
  StyleMenuListing->None],
Cell[16548, 638, 116, 4, 38, 22, 0, "StyleData", "TBI", "All",
  StyleMenuListing->None],
Cell[16667, 644, 117, 4, 36, 21, 0, "StyleData", "MR", "All",
  StyleMenuListing->None],
Cell[16787, 650, 118, 4, 37, 21, 0, "StyleData", "MO", "All",
  StyleMenuListing->None],
Cell[16908, 656, 116, 4, 37, 21, 0, "StyleData", "MB", "All",
  StyleMenuListing->None],
Cell[17027, 662, 118, 4, 37, 22, 0, "StyleData", "MBO", "All",
  StyleMenuListing->None],
Cell[17148, 668, 119, 4, 36, 21, 0, "StyleData", "SR", "All",
  StyleMenuListing->None],
Cell[17270, 674, 120, 4, 38, 21, 0, "StyleData", "SO", "All",
  StyleMenuListing->None],
Cell[17393, 680, 118, 4, 38, 21, 0, "StyleData", "SB", "All",
  StyleMenuListing->None],
Cell[17514, 686, 120, 4, 38, 22, 0, "StyleData", "SBO", "All",
  StyleMenuListing->None],

Cell[CellGroupData[{
Cell[17659, 694, 138, 5, 35, 23, 0, "StyleData", "SO10", "All",
  StyleMenuListing->None],
Cell[17800, 701, 149, 5, 70, 35, 0, "StyleData", "SO10", "Printout",
  StyleMenuListing->None],
Cell[17952, 708, 154, 5, 70, 43, 0, "StyleData", "SO10", "EnhancedPrintout",
  StyleMenuListing->None]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[18155, 719, 39, 0, 36, "Section"],

Cell[CellGroupData[{
Cell[18219, 723, 160, 5, 28, 33, 0, "StyleData", "PictureCaption", "All",
  StyleMenuListing->None],
Cell[18382, 730, 94, 2, 29, 45, 0, "StyleData", "PictureCaption", \
"Printout"],
Cell[18479, 734, 126, 3, 31, 53, 0, "StyleData", "PictureCaption", \
"EnhancedPrintout"],
Cell[18608, 739, 133, 3, 31, 60, 0, "StyleData", "PictureCaption", \
"EnhancedPrintoutNonGray"]
}, Closed]],

Cell[CellGroupData[{
Cell[18778, 747, 215, 6, 32, 30, 0, "StyleData", "MathCaption", "All"],
Cell[18996, 755, 120, 3, 70, 42, 0, "StyleData", "MathCaption", "Printout"],
Cell[19119, 760, 154, 4, 70, 50, 0, "StyleData", "MathCaption", \
"EnhancedPrintout"],
Cell[19276, 766, 161, 4, 70, 57, 0, "StyleData", "MathCaption", \
"EnhancedPrintoutNonGray"]
}, Closed]],

Cell[CellGroupData[{
Cell[19474, 775, 256, 8, 41, 29, 0, "StyleData", "Commentary", "All"],
Cell[19733, 785, 125, 3, 70, 41, 0, "StyleData", "Commentary", "Printout"],
Cell[19861, 790, 159, 4, 70, 49, 0, "StyleData", "Commentary", \
"EnhancedPrintout"],
Cell[20023, 796, 166, 4, 70, 56, 0, "StyleData", "Commentary", \
"EnhancedPrintoutNonGray"]
}, Closed]],

Cell[CellGroupData[{
Cell[20226, 805, 177, 5, 32, 31, 0, "StyleData", "ItemizedText", "All",
  CounterIncrements->"ItemizedText"],
Cell[20406, 812, 83, 2, 70, 43, 0, "StyleData", "ItemizedText", "Printout"],
Cell[20492, 816, 117, 3, 70, 51, 0, "StyleData", "ItemizedText", \
"EnhancedPrintout"],
Cell[20612, 821, 124, 3, 70, 58, 0, "StyleData", "ItemizedText", \
"EnhancedPrintoutNonGray"]
}, Closed]],

Cell[CellGroupData[{
Cell[20773, 829, 149, 4, 32, 35, 0, "StyleData", "ItemizedTextNote", "All",
  CounterIncrements->"Text"],
Cell[20925, 835, 97, 2, 70, 47, 0, "StyleData", "ItemizedTextNote", \
"Printout"],
Cell[21025, 839, 131, 3, 70, 55, 0, "StyleData", "ItemizedTextNote", \
"EnhancedPrintout"],
Cell[21159, 844, 138, 3, 70, 62, 0, "StyleData", "ItemizedTextNote", \
"EnhancedPrintoutNonGray"]
}, Closed]],

Cell[CellGroupData[{
Cell[21334, 852, 138, 4, 32, 29, 0, "StyleData", "BulletText", "All"],
Cell[21475, 858, 81, 2, 70, 41, 0, "StyleData", "BulletText", "Printout"],
Cell[21559, 862, 115, 3, 70, 49, 0, "StyleData", "BulletText", \
"EnhancedPrintout"],
Cell[21677, 867, 122, 3, 70, 56, 0, "StyleData", "BulletText", \
"EnhancedPrintoutNonGray"]
}, Closed]],

Cell[CellGroupData[{
Cell[21836, 875, 145, 4, 32, 31, 0, "StyleData", "IndentedText", "All",
  CounterIncrements->"Text"],
Cell[21984, 881, 59, 1, 70, 43, 0, "StyleData", "IndentedText", "Printout"],
Cell[22046, 884, 93, 2, 70, 51, 0, "StyleData", "IndentedText", \
"EnhancedPrintout"],
Cell[22142, 888, 100, 2, 70, 58, 0, "StyleData", "IndentedText", \
"EnhancedPrintoutNonGray"]
}, Closed]],

Cell[CellGroupData[{
Cell[22279, 895, 410, 12, 56, 32, 0, "StyleData", "HiddenSection", "All",
  CounterIncrements->"Section",
  CounterAssignments->{{"Subsection", 0}, {"Subsubsection", 0}},
  CellTags->"Section"],
Cell[22692, 909, 174, 5, 163, 44, 0, "StyleData", "HiddenSection", \
"Printout"],
Cell[22869, 916, 206, 6, 168, 52, 0, "StyleData", "HiddenSection", \
"EnhancedPrintout"],
Cell[23078, 924, 213, 6, 168, 59, 0, "StyleData", "HiddenSection", \
"EnhancedPrintoutNonGray"]
}, Closed]],

Cell[CellGroupData[{
Cell[23328, 935, 202, 5, 31, 30, 0, "StyleData", "CompactText", "All",
  StyleMenuListing->None],
Cell[23533, 942, 90, 2, 32, 42, 0, "StyleData", "CompactText", "Printout"],
Cell[23626, 946, 148, 4, 33, 50, 0, "StyleData", "CompactText", \
"EnhancedPrintout"],
Cell[23777, 952, 155, 4, 33, 57, 0, "StyleData", "CompactText", \
"EnhancedPrintoutNonGray"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[23981, 962, 46, 0, 36, "Section"],

Cell[CellGroupData[{
Cell[24052, 966, 434, 15, 55, 32, 0, "StyleData", "DefinitionBox", "All",
  StyleMenuListing->None],
Cell[24489, 983, 128, 3, 70, 44, 0, "StyleData", "DefinitionBox", \
"Printout"],
Cell[24620, 988, 162, 4, 70, 52, 0, "StyleData", "DefinitionBox", \
"EnhancedPrintout"],
Cell[24785, 994, 169, 4, 70, 59, 0, "StyleData", "DefinitionBox", \
"EnhancedPrintoutNonGray"]
}, Closed]],

Cell[CellGroupData[{
Cell[24991, 1003, 443, 15, 51, 36, 0, "StyleData", "DefinitionBox3Col", "All",
  
  StyleMenuListing->None],
Cell[25437, 1020, 132, 3, 70, 48, 0, "StyleData", "DefinitionBox3Col", \
"Printout"],
Cell[25572, 1025, 166, 4, 70, 56, 0, "StyleData", "DefinitionBox3Col", \
"EnhancedPrintout"],
Cell[25741, 1031, 173, 4, 70, 63, 0, "StyleData", "DefinitionBox3Col", \
"EnhancedPrintoutNonGray"]
}, Closed]],

Cell[CellGroupData[{
Cell[25951, 1040, 452, 15, 51, 36, 0, "StyleData", "DefinitionBox4Col", "All",
  
  StyleMenuListing->None],
Cell[26406, 1057, 132, 3, 70, 48, 0, "StyleData", "DefinitionBox4Col", \
"Printout"],
Cell[26541, 1062, 166, 4, 70, 56, 0, "StyleData", "DefinitionBox4Col", \
"EnhancedPrintout"],
Cell[26710, 1068, 173, 4, 70, 63, 0, "StyleData", "DefinitionBox4Col", \
"EnhancedPrintoutNonGray"]
}, Closed]],

Cell[CellGroupData[{
Cell[26920, 1077, 431, 15, 51, 36, 0, "StyleData", "DefinitionBox5Col", "All",
  
  StyleMenuListing->None],
Cell[27354, 1094, 132, 3, 70, 48, 0, "StyleData", "DefinitionBox5Col", \
"Printout"],
Cell[27489, 1099, 166, 4, 70, 56, 0, "StyleData", "DefinitionBox5Col", \
"EnhancedPrintout"],
Cell[27658, 1105, 173, 4, 70, 63, 0, "StyleData", "DefinitionBox5Col", \
"EnhancedPrintoutNonGray"]
}, Closed]],

Cell[CellGroupData[{
Cell[27868, 1114, 464, 15, 51, 36, 0, "StyleData", "DefinitionBox6Col", "All",
  
  StyleMenuListing->None],
Cell[28335, 1131, 132, 3, 70, 48, 0, "StyleData", "DefinitionBox6Col", \
"Printout"],
Cell[28470, 1136, 166, 4, 70, 56, 0, "StyleData", "DefinitionBox6Col", \
"EnhancedPrintout"],
Cell[28639, 1142, 173, 4, 70, 63, 0, "StyleData", "DefinitionBox6Col", \
"EnhancedPrintoutNonGray"]
}, Closed]],

Cell[CellGroupData[{
Cell[28849, 1151, 447, 15, 50, 25, 0, "StyleData", "TopBox", "All",
  StyleMenuListing->None],
Cell[29299, 1168, 122, 3, 70, 37, 0, "StyleData", "TopBox", "Printout"],
Cell[29424, 1173, 156, 4, 70, 45, 0, "StyleData", "TopBox", \
"EnhancedPrintout"],
Cell[29583, 1179, 163, 4, 70, 52, 0, "StyleData", "TopBox", \
"EnhancedPrintoutNonGray"]
}, Closed]],

Cell[CellGroupData[{
Cell[29783, 1188, 512, 17, 42, 28, 0, "StyleData", "MiddleBox", "All",
  StyleMenuListing->None],
Cell[30298, 1207, 163, 4, 70, 40, 0, "StyleData", "MiddleBox", "Printout"],
Cell[30464, 1213, 197, 5, 70, 48, 0, "StyleData", "MiddleBox", \
"EnhancedPrintout"],
Cell[30664, 1220, 204, 5, 70, 55, 0, "StyleData", "MiddleBox", \
"EnhancedPrintoutNonGray"]
}, Closed]],

Cell[CellGroupData[{
Cell[30905, 1230, 502, 17, 47, 34, 0, "StyleData", "MiddleSpacedBox", "All",
  StyleMenuListing->None],
Cell[31410, 1249, 208, 5, 70, 46, 0, "StyleData", "MiddleSpacedBox", \
"Printout"],
Cell[31621, 1256, 242, 6, 70, 54, 0, "StyleData", "MiddleSpacedBox", \
"EnhancedPrintout"],
Cell[31866, 1264, 249, 6, 70, 61, 0, "StyleData", "MiddleSpacedBox", \
"EnhancedPrintoutNonGray"]
}, Closed]],

Cell[CellGroupData[{
Cell[32152, 1275, 499, 17, 47, 32, 0, "StyleData", "MiddleSpanBox", "All",
  StyleMenuListing->None],
Cell[32654, 1294, 206, 5, 70, 44, 0, "StyleData", "MiddleSpanBox", \
"Printout"],
Cell[32863, 1301, 240, 6, 70, 52, 0, "StyleData", "MiddleSpanBox", \
"EnhancedPrintout"],
Cell[33106, 1309, 247, 6, 70, 59, 0, "StyleData", "MiddleSpanBox", \
"EnhancedPrintoutNonGray"]
}, Closed]],

Cell[CellGroupData[{
Cell[33390, 1320, 497, 17, 50, 28, 0, "StyleData", "BottomBox", "All",
  StyleMenuListing->None],
Cell[33890, 1339, 204, 5, 26, 40, 0, "StyleData", "BottomBox", "Printout"],
Cell[34097, 1346, 238, 6, 27, 48, 0, "StyleData", "BottomBox", \
"EnhancedPrintout"],
Cell[34338, 1354, 245, 6, 27, 55, 0, "StyleData", "BottomBox", \
"EnhancedPrintoutNonGray"]
}, Closed]],

Cell[CellGroupData[{
Cell[34620, 1365, 451, 15, 48, 29, 0, "StyleData", "TopSpanBox", "All",
  StyleMenuListing->None],
Cell[35074, 1382, 126, 3, 70, 41, 0, "StyleData", "TopSpanBox", "Printout"],
Cell[35203, 1387, 160, 4, 70, 49, 0, "StyleData", "TopSpanBox", \
"EnhancedPrintout"],
Cell[35366, 1393, 167, 4, 70, 56, 0, "StyleData", "TopSpanBox", \
"EnhancedPrintoutNonGray"]
}, Closed]],

Cell[CellGroupData[{
Cell[35570, 1402, 101, 2, 32, 26, 0, "StyleData", "Picture", "All"],
Cell[35674, 1406, 79, 1, 70, 38, 0, "StyleData", "Picture", "Printout"],
Cell[35756, 1409, 87, 1, 70, 46, 0, "StyleData", "Picture", \
"EnhancedPrintout"],
Cell[35846, 1412, 94, 1, 70, 53, 0, "StyleData", "Picture", \
"EnhancedPrintoutNonGray"]
}, Closed]],

Cell[CellGroupData[{
Cell[35977, 1418, 127, 4, 30, 26, 0, "StyleData", "Caption", "All"],
Cell[36107, 1424, 86, 2, 70, 38, 0, "StyleData", "Caption", "Printout"],
Cell[36196, 1428, 118, 3, 70, 46, 0, "StyleData", "Caption", \
"EnhancedPrintout"],
Cell[36317, 1433, 125, 3, 70, 53, 0, "StyleData", "Caption", \
"EnhancedPrintoutNonGray"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[36491, 1442, 25, 0, 36, "Section"],

Cell[CellGroupData[{
Cell[36541, 1446, 329, 11, 70, 33, 0, "StyleData", "SingleRowTable", "All",
  StyleMenuListing->None],
Cell[36873, 1459, 94, 2, 70, 45, 0, "StyleData", "SingleRowTable", \
"Printout"],
Cell[36970, 1463, 102, 2, 70, 53, 0, "StyleData", "SingleRowTable", \
"EnhancedPrintout"],
Cell[37075, 1467, 109, 2, 70, 60, 0, "StyleData", "SingleRowTable", \
"EnhancedPrintoutNonGray"]
}, Closed]],

Cell[CellGroupData[{
Cell[37221, 1474, 365, 12, 70, 31, 0, "StyleData", "2ColumnTable", "All",
  StyleMenuListing->None],
Cell[37589, 1488, 92, 2, 70, 43, 0, "StyleData", "2ColumnTable", "Printout"],
Cell[37684, 1492, 100, 2, 70, 51, 0, "StyleData", "2ColumnTable", \
"EnhancedPrintout"],
Cell[37787, 1496, 107, 2, 70, 58, 0, "StyleData", "2ColumnTable", \
"EnhancedPrintoutNonGray"]
}, Closed]],

Cell[CellGroupData[{
Cell[37931, 1503, 361, 12, 70, 35, 0, "StyleData", "2ColumnEvenTable", "All",
  StyleMenuListing->None],
Cell[38295, 1517, 96, 2, 70, 47, 0, "StyleData", "2ColumnEvenTable", \
"Printout"],
Cell[38394, 1521, 104, 2, 70, 55, 0, "StyleData", "2ColumnEvenTable", \
"EnhancedPrintout"],
Cell[38501, 1525, 111, 2, 70, 62, 0, "StyleData", "2ColumnEvenTable", \
"EnhancedPrintoutNonGray"]
}, Closed]],

Cell[CellGroupData[{
Cell[38649, 1532, 442, 13, 70, 31, 0, "StyleData", "3ColumnTable", "All",
  CounterIncrements->"Table",
  StyleMenuListing->None],
Cell[39094, 1547, 93, 2, 70, 43, 0, "StyleData", "3ColumnTable", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[39224, 1554, 447, 13, 70, 36, 0, "StyleData", "3ColumnTablePlain", "All",
  
  CounterIncrements->"Table",
  StyleMenuListing->None],
Cell[39674, 1569, 98, 2, 70, 48, 0, "StyleData", "3ColumnTablePlain", \
"Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[39809, 1576, 442, 13, 70, 31, 0, "StyleData", "4ColumnTable", "All",
  CounterIncrements->"Table",
  StyleMenuListing->None],
Cell[40254, 1591, 93, 2, 70, 43, 0, "StyleData", "4ColumnTable", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[40384, 1598, 447, 13, 70, 36, 0, "StyleData", "4ColumnTablePlain", "All",
  
  CounterIncrements->"Table",
  StyleMenuListing->None],
Cell[40834, 1613, 98, 2, 70, 48, 0, "StyleData", "4ColumnTablePlain", \
"Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[40969, 1620, 442, 13, 70, 31, 0, "StyleData", "5ColumnTable", "All",
  CounterIncrements->"Table",
  StyleMenuListing->None],
Cell[41414, 1635, 93, 2, 70, 43, 0, "StyleData", "5ColumnTable", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[41544, 1642, 447, 13, 70, 36, 0, "StyleData", "5ColumnTablePlain", "All",
  
  CounterIncrements->"Table",
  StyleMenuListing->None],
Cell[41994, 1657, 98, 2, 70, 48, 0, "StyleData", "5ColumnTablePlain", \
"Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[42129, 1664, 357, 12, 70, 31, 0, "StyleData", "6ColumnTable", "All",
  StyleMenuListing->None],
Cell[42489, 1678, 92, 2, 70, 43, 0, "StyleData", "6ColumnTable", "Printout"],
Cell[42584, 1682, 100, 2, 70, 51, 0, "StyleData", "6ColumnTable", \
"EnhancedPrintout"],
Cell[42687, 1686, 107, 2, 70, 58, 0, "StyleData", "6ColumnTable", \
"EnhancedPrintoutNonGray"]
}, Closed]],

Cell[CellGroupData[{
Cell[42831, 1693, 357, 12, 70, 31, 0, "StyleData", "7ColumnTable", "All",
  StyleMenuListing->None],
Cell[43191, 1707, 92, 2, 70, 43, 0, "StyleData", "7ColumnTable", "Printout"],
Cell[43286, 1711, 100, 2, 70, 51, 0, "StyleData", "7ColumnTable", \
"EnhancedPrintout"],
Cell[43389, 1715, 107, 2, 70, 58, 0, "StyleData", "7ColumnTable", \
"EnhancedPrintoutNonGray"]
}, Closed]],

Cell[CellGroupData[{
Cell[43533, 1722, 357, 12, 70, 31, 0, "StyleData", "8ColumnTable", "All",
  StyleMenuListing->None],
Cell[43893, 1736, 92, 2, 70, 43, 0, "StyleData", "8ColumnTable", "Printout"],
Cell[43988, 1740, 100, 2, 70, 51, 0, "StyleData", "8ColumnTable", \
"EnhancedPrintout"],
Cell[44091, 1744, 107, 2, 70, 58, 0, "StyleData", "8ColumnTable", \
"EnhancedPrintoutNonGray"]
}, Closed]],

Cell[CellGroupData[{
Cell[44235, 1751, 275, 9, 70, 28, 0, "StyleData", "TableHead", "All",
  CounterIncrements->"TableHead",
  StyleMenuListing->None],
Cell[44513, 1762, 56, 1, 70, 40, 0, "StyleData", "TableHead", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[44606, 1768, 435, 13, 70, 24, 0, "StyleData", "Table", "All",
  CounterIncrements->"Table",
  StyleMenuListing->None],
Cell[45044, 1783, 86, 2, 70, 36, 0, "StyleData", "Table", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[45167, 1790, 440, 13, 70, 29, 0, "StyleData", "TablePlain", "All",
  CounterIncrements->"Table",
  StyleMenuListing->None],
Cell[45610, 1805, 91, 2, 70, 41, 0, "StyleData", "TablePlain", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[45738, 1812, 173, 6, 70, 28, 0, "StyleData", "TableNote", "All"],
Cell[45914, 1820, 55, 1, 70, 40, 0, "StyleData", "TableNote", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[46006, 1826, 46, 0, 70, "Subsection"],

Cell[CellGroupData[{
Cell[46077, 1830, 112, 3, 70, 32, 0, "StyleData", "TableHeadText", "All",
  CounterIncrements->"TableHead"],
Cell[46192, 1835, 60, 1, 70, 44, 0, "StyleData", "TableHeadText", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[46289, 1841, 105, 3, 70, 29, 0, "StyleData", "ColumnHead", "All",
  CounterIncrements->"Table"],
Cell[46397, 1846, 57, 1, 70, 41, 0, "StyleData", "ColumnHead", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[46491, 1852, 113, 4, 70, 28, 0, "StyleData", "TableText", "All"],
Cell[46607, 1858, 56, 1, 70, 40, 0, "StyleData", "TableText", "Printout"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[46724, 1866, 49, 0, 36, "Section"],
Cell[46776, 1868, 225, 4, 70, "Text"],

Cell[CellGroupData[{
Cell[47026, 1876, 384, 9, 70, 35, 0, "StyleData", "NumberedEquation", "All",
  CounterIncrements->"NumberedEquation"],
Cell[47413, 1887, 99, 2, 70, 47, 0, "StyleData", "NumberedEquation", \
"Printout"],
Cell[47515, 1891, 133, 3, 70, 55, 0, "StyleData", "NumberedEquation", \
"EnhancedPrintout"],
Cell[47651, 1896, 140, 3, 70, 62, 0, "StyleData", "NumberedEquation", \
"EnhancedPrintoutNonGray"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[47840, 1905, 43, 0, 36, "Section"],

Cell[CellGroupData[{
Cell[47908, 1909, 236, 6, 70, 33, 0, "StyleData", "DisplayFormula", "All"],
Cell[48147, 1917, 61, 1, 70, 45, 0, "StyleData", "DisplayFormula", \
"Printout"],
Cell[48211, 1920, 95, 2, 70, 53, 0, "StyleData", "DisplayFormula", \
"EnhancedPrintout"],
Cell[48309, 1924, 102, 2, 70, 60, 0, "StyleData", "DisplayFormula", \
"EnhancedPrintoutNonGray"]
}, Closed]],

Cell[CellGroupData[{
Cell[48448, 1931, 389, 12, 70, 30, 0, "StyleData", "DisplayMath", "All",
  CounterIncrements->"Input"],
Cell[48840, 1945, 91, 2, 70, 42, 0, "StyleData", "DisplayMath", "Printout"],
Cell[48934, 1949, 127, 3, 70, 50, 0, "StyleData", "DisplayMath", \
"EnhancedPrintout"],
Cell[49064, 1954, 134, 3, 70, 57, 0, "StyleData", "DisplayMath", \
"EnhancedPrintoutNonGray"]
}, Closed]],

Cell[CellGroupData[{
Cell[49235, 1962, 59, 1, 70, 33, 0, "StyleData", "EquationNumber", "All"],
Cell[49297, 1965, 86, 2, 70, 45, 0, "StyleData", "EquationNumber", \
"Printout"],
Cell[49386, 1969, 120, 3, 70, 53, 0, "StyleData", "EquationNumber", \
"EnhancedPrintout"],
Cell[49509, 1974, 127, 3, 70, 60, 0, "StyleData", "EquationNumber", \
"EnhancedPrintoutNonGray"]
}, Closed]],

Cell[CellGroupData[{
Cell[49673, 1982, 166, 4, 70, 26, 0, "StyleData", "Program", "All"],
Cell[49842, 1988, 98, 2, 70, 38, 0, "StyleData", "Program", "Printout"],
Cell[49943, 1992, 134, 3, 70, 46, 0, "StyleData", "Program", \
"EnhancedPrintout"],
Cell[50080, 1997, 141, 3, 70, 53, 0, "StyleData", "Program", \
"EnhancedPrintoutNonGray"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[50270, 2006, 37, 0, 36, "Section"],

Cell[CellGroupData[{
Cell[50332, 2010, 133, 4, 165, 32, 0, "StyleData", "ContentsTitle", "All"],
Cell[50468, 2016, 121, 3, 132, 44, 0, "StyleData", "ContentsTitle", \
"Printout"],
Cell[50592, 2021, 153, 4, 137, 52, 0, "StyleData", "ContentsTitle", \
"EnhancedPrintout"]
}, Closed]],

Cell[CellGroupData[{
Cell[50782, 2030, 238, 7, 37, 34, 0, "StyleData", "ContentsSection", "All",
  StyleMenuListing->None],
Cell[51023, 2039, 122, 3, 70, 46, 0, "StyleData", "ContentsSection", \
"Printout"],
Cell[51148, 2044, 154, 4, 70, 54, 0, "StyleData", "ContentsSection", \
"EnhancedPrintout"],
Cell[51305, 2050, 161, 4, 70, 61, 0, "StyleData", "ContentsSection", \
"EnhancedPrintoutNonGray"]
}, Closed]],

Cell[CellGroupData[{
Cell[51503, 2059, 191, 6, 39, 31, 0, "StyleData", "IndexSection", "All",
  StyleMenuListing->None],
Cell[51697, 2067, 119, 3, 70, 43, 0, "StyleData", "IndexSection", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[51853, 2075, 166, 4, 34, 27, 0, "StyleData", "Contents", "All",
  StyleMenuListing->None],
Cell[52022, 2081, 89, 2, 70, 39, 0, "StyleData", "Contents", "Printout"],
Cell[52114, 2085, 123, 3, 70, 47, 0, "StyleData", "Contents", \
"EnhancedPrintout"],
Cell[52240, 2090, 130, 3, 70, 54, 0, "StyleData", "Contents", \
"EnhancedPrintoutNonGray"]
}, Closed]],

Cell[CellGroupData[{
Cell[52407, 2098, 108, 3, 34, 24, 0, "StyleData", "Index", "All",
  StyleMenuListing->None],
Cell[52518, 2103, 86, 2, 70, 36, 0, "StyleData", "Index", "Printout"],
Cell[52607, 2107, 120, 3, 70, 44, 0, "StyleData", "Index", \
"EnhancedPrintout"],
Cell[52730, 2112, 127, 3, 70, 51, 0, "StyleData", "Index", \
"EnhancedPrintoutNonGray"]
}, Closed]],

Cell[CellGroupData[{
Cell[52894, 2120, 116, 3, 34, 32, 0, "StyleData", "IndexSubentry", "All",
  StyleMenuListing->None],
Cell[53013, 2125, 94, 2, 70, 44, 0, "StyleData", "IndexSubentry", \
"Printout"],
Cell[53110, 2129, 128, 3, 70, 52, 0, "StyleData", "IndexSubentry", \
"EnhancedPrintout"],
Cell[53241, 2134, 135, 3, 70, 59, 0, "StyleData", "IndexSubentry", \
"EnhancedPrintoutNonGray"]
}, Closed]],

Cell[CellGroupData[{
Cell[53413, 2142, 200, 6, 34, 31, 0, "StyleData", "Index2Column", "All",
  StyleMenuListing->None],
Cell[53616, 2150, 116, 3, 39, 43, 0, "StyleData", "Index2Column", \
"Printout"],
Cell[53735, 2155, 150, 4, 40, 51, 0, "StyleData", "Index2Column", \
"EnhancedPrintout"],
Cell[53888, 2161, 157, 4, 40, 58, 0, "StyleData", "Index2Column", \
"EnhancedPrintoutNonGray"]
}, Closed]],

Cell[CellGroupData[{
Cell[54082, 2170, 113, 4, 38, 25, 0, "StyleData", "Leader", "All",
  StyleMenuListing->None],
Cell[54198, 2176, 53, 1, 70, 37, 0, "StyleData", "Leader", "Printout"],
Cell[54254, 2179, 87, 2, 70, 45, 0, "StyleData", "Leader", \
"EnhancedPrintout"]
}, Closed]],

Cell[CellGroupData[{
Cell[54378, 2186, 343, 11, 38, 27, 0, "StyleData", "PageLink", "All",
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic],
Cell[54724, 2199, 82, 2, 35, 39, 0, "StyleData", "PageLink", "Printout"],
Cell[54809, 2203, 90, 2, 35, 47, 0, "StyleData", "PageLink", \
"EnhancedPrintout"]
}, Closed]],

Cell[CellGroupData[{
Cell[54936, 2210, 167, 6, 38, 26, 0, "StyleData", "TOCPage", "All",
  StyleMenuListing->None],
Cell[55106, 2218, 54, 1, 70, 38, 0, "StyleData", "TOCPage", "Printout"],
Cell[55163, 2221, 88, 2, 70, 46, 0, "StyleData", "TOCPage", \
"EnhancedPrintout"]
}, Closed]],

Cell[CellGroupData[{
Cell[55288, 2228, 267, 8, 35, 27, 0, "StyleData", "TOCTitle", "All",
  CounterIncrements->"TOCTitle",
  CounterAssignments->{{"TOCSection", 0}}],
Cell[55558, 2238, 135, 4, 36, 39, 0, "StyleData", "TOCTitle", "Printout"],
Cell[55696, 2244, 167, 5, 37, 47, 0, "StyleData", "TOCTitle", \
"EnhancedPrintout"]
}, Closed]],

Cell[CellGroupData[{
Cell[55900, 2254, 254, 7, 35, 29, 0, "StyleData", "TOCSection", "All",
  CounterIncrements->"TOCSection",
  CounterAssignments->{{"TOCSubsection", 0}}],
Cell[56157, 2263, 137, 4, 29, 41, 0, "StyleData", "TOCSection", "Printout"],
Cell[56297, 2269, 171, 5, 30, 49, 0, "StyleData", "TOCSection", \
"EnhancedPrintout"]
}, Closed]],

Cell[CellGroupData[{
Cell[56505, 2279, 236, 6, 35, 32, 0, "StyleData", "TOCSubsection", "All",
  CounterIncrements->"TOCSubsection",
  CounterAssignments->{{"TOCSubsubsection", 0}}],
Cell[56744, 2287, 119, 3, 29, 44, 0, "StyleData", "TOCSubsection", \
"Printout"],
Cell[56866, 2292, 153, 4, 30, 52, 0, "StyleData", "TOCSubsection", \
"EnhancedPrintout"]
}, Closed]],

Cell[CellGroupData[{
Cell[57056, 2301, 194, 5, 35, 35, 0, "StyleData", "TOCSubsubsection", "All",
  CounterIncrements->"TOCSubsubsection"],
Cell[57253, 2308, 121, 3, 28, 47, 0, "StyleData", "TOCSubsubsection", \
"Printout"],
Cell[57377, 2313, 155, 4, 27, 55, 0, "StyleData", "TOCSubsubsection", \
"EnhancedPrintout"]
}, Closed]],

Cell[CellGroupData[{
Cell[57569, 2322, 334, 9, 35, 36, 0, "StyleData", "TOCTitleCondensed", "All",
  CounterIncrements->"TOCTitleCondensed",
  CounterAssignments->{{"TOCSectionCondensed", 0}, {
      "TOCSubsectionCondensed", 0}}],
Cell[57906, 2333, 123, 3, 36, 48, 0, "StyleData", "TOCTitleCondensed", \
"Printout"],
Cell[58032, 2338, 155, 4, 37, 56, 0, "StyleData", "TOCTitleCondensed", \
"EnhancedPrintout"]
}, Closed]],

Cell[CellGroupData[{
Cell[58224, 2347, 323, 9, 32, 38, 0, "StyleData", "TOCSectionCondensed", \
"All",
  CounterIncrements->"TOCSectionCondensed",
  CounterAssignments->{{"TOCSubsection", 0}}],
Cell[58550, 2358, 125, 3, 29, 50, 0, "StyleData", "TOCSectionCondensed", \
"Printout"],
Cell[58678, 2363, 159, 4, 30, 58, 0, "StyleData", "TOCSectionCondensed", \
"EnhancedPrintout"]
}, Closed]],

Cell[CellGroupData[{
Cell[58874, 2372, 179, 5, 35, 41, 0, "StyleData", "TOCSubsectionCondensed", \
"All"],
Cell[59056, 2379, 128, 3, 29, 53, 0, "StyleData", "TOCSubsectionCondensed", \
"Printout"],
Cell[59187, 2384, 162, 4, 30, 61, 0, "StyleData", "TOCSubsectionCondensed", \
"EnhancedPrintout"]
}, Closed]],

Cell[CellGroupData[{
Cell[59386, 2393, 212, 5, 35, 44, 0, "StyleData", \
"TOCSubsubsectionCondensed", "All",
  CounterIncrements->"TOCSubsubsectionCondensed"],
Cell[59601, 2400, 130, 3, 28, 56, 0, "StyleData", \
"TOCSubsubsectionCondensed", "Printout"],
Cell[59734, 2405, 164, 4, 27, 64, 0, "StyleData", \
"TOCSubsubsectionCondensed", "EnhancedPrintout"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[59947, 2415, 32, 0, 36, "Section"],

Cell[CellGroupData[{
Cell[60004, 2419, 264, 8, 70, 31, 0, "StyleData", "FunctionName", "All",
  CellTags->"FunctionName"],
Cell[60271, 2429, 94, 2, 70, 43, 0, "StyleData", "FunctionName", "Printout"],
Cell[60368, 2433, 127, 3, 70, 51, 0, "StyleData", "FunctionName", \
"EnhancedPrintout"],
Cell[60498, 2438, 134, 3, 70, 58, 0, "StyleData", "FunctionName", \
"EnhancedPrintoutNonGray"]
}, Closed]],

Cell[CellGroupData[{
Cell[60669, 2446, 241, 7, 70, 33, 0, "StyleData", "SubsectionIcon", "All",
  CellTags->"FunctionSection"],
Cell[60913, 2455, 96, 2, 70, 45, 0, "StyleData", "SubsectionIcon", \
"Printout"],
Cell[61012, 2459, 130, 3, 70, 53, 0, "StyleData", "SubsectionIcon", \
"EnhancedPrintout"],
Cell[61145, 2464, 137, 3, 70, 60, 0, "StyleData", "SubsectionIcon", \
"EnhancedPrintoutNonGray"]
}, Closed]],

Cell[CellGroupData[{
Cell[61319, 2472, 233, 6, 70, 37, 0, "StyleData", "FunctionSubsection", \
"All",
  CellTags->"FunctionSubsection"],
Cell[61555, 2480, 83, 1, 70, 49, 0, "StyleData", "FunctionSubsection", \
"Printout"],
Cell[61641, 2483, 133, 3, 70, 57, 0, "StyleData", "FunctionSubsection", \
"EnhancedPrintout"],
Cell[61777, 2488, 140, 3, 70, 64, 0, "StyleData", "FunctionSubsection", \
"EnhancedPrintoutNonGray"]
}, Closed]],

Cell[CellGroupData[{
Cell[61954, 2496, 229, 6, 70, 36, 0, "StyleData", "SubsubsectionIcon", "All",
  CellTags->"SubsubsectionIcon"],
Cell[62186, 2504, 98, 2, 70, 48, 0, "StyleData", "SubsubsectionIcon", \
"Printout"],
Cell[62287, 2508, 131, 3, 70, 56, 0, "StyleData", "SubsubsectionIcon", \
"EnhancedPrintout"],
Cell[62421, 2513, 138, 3, 70, 63, 0, "StyleData", "SubsubsectionIcon", \
"EnhancedPrintoutNonGray"]
}, Closed]],

Cell[CellGroupData[{
Cell[62596, 2521, 178, 5, 70, 38, 0, "StyleData", "FunctionDescription", \
"All",
  CounterIncrements->"Text"],
Cell[62777, 2528, 100, 2, 70, 50, 0, "StyleData", "FunctionDescription", \
"Printout"],
Cell[62880, 2532, 158, 4, 70, 58, 0, "StyleData", "FunctionDescription", \
"EnhancedPrintout"],
Cell[63041, 2538, 165, 4, 70, 65, 0, "StyleData", "FunctionDescription", \
"EnhancedPrintoutNonGray"]
}, Closed]],

Cell[CellGroupData[{
Cell[63243, 2547, 197, 5, 70, 43, 0, "StyleData", "FunctionDescriptionRuled", \
"All",
  CounterIncrements->"Text"],
Cell[63443, 2554, 105, 2, 70, 55, 0, "StyleData", "FunctionDescriptionRuled", \
"Printout"],
Cell[63551, 2558, 163, 4, 70, 63, 0, "StyleData", "FunctionDescriptionRuled", \
"EnhancedPrintout"],
Cell[63717, 2564, 170, 4, 70, 70, 0, "StyleData", "FunctionDescriptionRuled", \
"EnhancedPrintoutNonGray"]
}, Closed]],

Cell[CellGroupData[{
Cell[63924, 2573, 196, 5, 70, 45, 0, "StyleData", \
"FunctionDescriptionRuleTop", "All",
  CounterIncrements->"Text"],
Cell[64123, 2580, 107, 2, 70, 57, 0, "StyleData", \
"FunctionDescriptionRuleTop", "Printout"],
Cell[64233, 2584, 165, 4, 70, 65, 0, "StyleData", \
"FunctionDescriptionRuleTop", "EnhancedPrintout"],
Cell[64401, 2590, 172, 4, 70, 72, 0, "StyleData", \
"FunctionDescriptionRuleTop", "EnhancedPrintoutNonGray"]
}, Closed]],

Cell[CellGroupData[{
Cell[64610, 2599, 199, 5, 70, 48, 0, "StyleData", \
"FunctionDescriptionRuleBottom", "All",
  CounterIncrements->"Text"],
Cell[64812, 2606, 110, 2, 70, 60, 0, "StyleData", \
"FunctionDescriptionRuleBottom", "Printout"],
Cell[64925, 2610, 168, 4, 70, 68, 0, "StyleData", \
"FunctionDescriptionRuleBottom", "EnhancedPrintout"],
Cell[65096, 2616, 175, 4, 70, 75, 0, "StyleData", \
"FunctionDescriptionRuleBottom", "EnhancedPrintoutNonGray"]
}, Closed]],

Cell[CellGroupData[{
Cell[65308, 2625, 111, 3, 70, 34, 0, "StyleData", "FunctionExample", "All",
  StyleMenuListing->None],
Cell[65422, 2630, 95, 2, 70, 46, 0, "StyleData", "FunctionExample", \
"Printout"],
Cell[65520, 2634, 129, 3, 70, 54, 0, "StyleData", "FunctionExample", \
"EnhancedPrintout"],
Cell[65652, 2639, 136, 3, 70, 61, 0, "StyleData", "FunctionExample", \
"EnhancedPrintoutNonGray"]
}, Closed]],

Cell[CellGroupData[{
Cell[65825, 2647, 137, 4, 70, 35, 0, "StyleData", "FunctionTextNote", "All"],
Cell[65965, 2653, 96, 2, 70, 47, 0, "StyleData", "FunctionTextNote", \
"Printout"],
Cell[66064, 2657, 130, 3, 70, 55, 0, "StyleData", "FunctionTextNote", \
"EnhancedPrintout"],
Cell[66197, 2662, 137, 3, 70, 62, 0, "StyleData", "FunctionTextNote", \
"EnhancedPrintoutNonGray"]
}, Closed]],

Cell[CellGroupData[{
Cell[66371, 2670, 315, 10, 70, 39, 0, "StyleData", "3ColumnFunctionTable", \
"All"],
Cell[66689, 2682, 101, 2, 70, 51, 0, "StyleData", "3ColumnFunctionTable", \
"Printout"],
Cell[66793, 2686, 109, 2, 70, 59, 0, "StyleData", "3ColumnFunctionTable", \
"EnhancedPrintout"],
Cell[66905, 2690, 116, 2, 70, 66, 0, "StyleData", "3ColumnFunctionTable", \
"EnhancedPrintoutNonGray"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[67070, 2698, 36, 0, 36, "Section"],

Cell[CellGroupData[{
Cell[67131, 2702, 155, 5, 70, 29, 0, "StyleData", "TextNormal", "All",
  CounterIncrements->"Text"],
Cell[67289, 2709, 90, 2, 70, 41, 0, "StyleData", "TextNormal", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[67416, 2716, 299, 9, 70, 35, 0, "StyleData", "BrowserEmulation", "All"],
Cell[67718, 2727, 84, 2, 70, 35, 0, "StyleData", "Text", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[67839, 2734, 259, 8, 70, 31, 0, "StyleData", "CategoryDefs", "All"],
Cell[68101, 2744, 84, 2, 70, 35, 0, "StyleData", "Text", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[68222, 2751, 205, 6, 70, 28, 0, "StyleData", "Category1", "All"],
Cell[68430, 2759, 73, 1, 70, 40, 0, "StyleData", "Category1", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[68540, 2765, 244, 7, 70, 28, 0, "StyleData", "Category2", "All"],
Cell[68787, 2774, 73, 1, 70, 40, 0, "StyleData", "Category2", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[68897, 2780, 242, 7, 70, 28, 0, "StyleData", "Category3", "All"],
Cell[69142, 2789, 73, 1, 70, 40, 0, "StyleData", "Category3", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[69252, 2795, 231, 6, 70, 28, 0, "StyleData", "Category4", "All"],
Cell[69486, 2803, 73, 1, 70, 40, 0, "StyleData", "Category4", "Printout"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[69608, 2810, 49, 0, 36, "Section"],

Cell[CellGroupData[{
Cell[69682, 2814, 148, 5, 70, 25, 0, "StyleData", "Header", "All",
  StyleMenuListing->None],
Cell[69833, 2821, 37, 0, 70, 37, 0, "StyleData", "Header", "Printout"],
Cell[69873, 2823, 69, 1, 70, 45, 0, "StyleData", "Header", \
"EnhancedPrintout"],
Cell[69945, 2826, 76, 1, 70, 52, 0, "StyleData", "Header", \
"EnhancedPrintoutNonGray"]
}, Closed]],

Cell[CellGroupData[{
Cell[70058, 2832, 148, 5, 70, 25, 0, "StyleData", "Footer", "All",
  StyleMenuListing->None],
Cell[70209, 2839, 37, 0, 70, 37, 0, "StyleData", "Footer", "Printout"],
Cell[70249, 2841, 69, 1, 70, 45, 0, "StyleData", "Footer", \
"EnhancedPrintout"],
Cell[70321, 2844, 76, 1, 70, 52, 0, "StyleData", "Footer", \
"EnhancedPrintoutNonGray"]
}, Closed]],

Cell[CellGroupData[{
Cell[70434, 2850, 152, 5, 70, 29, 0, "StyleData", "PageNumber", "All",
  StyleMenuListing->None],
Cell[70589, 2857, 41, 0, 70, 41, 0, "StyleData", "PageNumber", "Printout"],
Cell[70633, 2859, 73, 1, 70, 49, 0, "StyleData", "PageNumber", \
"EnhancedPrintout"],
Cell[70709, 2862, 80, 1, 70, 56, 0, "StyleData", "PageNumber", \
"EnhancedPrintoutNonGray"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[70838, 2869, 35, 0, 36, "Section"],
Cell[70876, 2871, 184, 4, 50, "Text"],

Cell[CellGroupData[{
Cell[71085, 2879, 302, 8, 38, 28, 0, "StyleData", "Hyperlink", "All",
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic],
Cell[71390, 2889, 123, 3, 70, 40, 0, "StyleData", "Hyperlink", "Printout"],
Cell[71516, 2894, 157, 4, 70, 48, 0, "StyleData", "Hyperlink", \
"EnhancedPrintout"],
Cell[71676, 2900, 164, 4, 70, 55, 0, "StyleData", "Hyperlink", \
"EnhancedPrintoutNonGray"]
}, Closed]],
Cell[71855, 2907, 104, 3, 29, "Text"],

Cell[CellGroupData[{
Cell[71984, 2914, 316, 8, 38, 31, 0, "StyleData", "MainBookLink", "All",
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic],
Cell[72303, 2924, 126, 3, 70, 43, 0, "StyleData", "MainBookLink", \
"Printout"],
Cell[72432, 2929, 160, 4, 70, 51, 0, "StyleData", "MainBookLink", \
"EnhancedPrintout"],
Cell[72595, 2935, 167, 4, 70, 58, 0, "StyleData", "MainBookLink", \
"EnhancedPrintoutNonGray"]
}, Closed]],

Cell[CellGroupData[{
Cell[72799, 2944, 343, 9, 37, 33, 0, "StyleData", "MainBookLinkMR", "All",
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic],
Cell[73145, 2955, 128, 3, 35, 45, 0, "StyleData", "MainBookLinkMR", \
"Printout"],
Cell[73276, 2960, 136, 3, 35, 53, 0, "StyleData", "MainBookLinkMR", \
"EnhancedPrintout"],
Cell[73415, 2965, 143, 3, 35, 60, 0, "StyleData", "MainBookLinkMR", \
"EnhancedPrintoutNonGray"]
}, Closed]],

Cell[CellGroupData[{
Cell[73595, 2973, 337, 9, 37, 29, 0, "StyleData", "AddOnsLink", "All",
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic],
Cell[73935, 2984, 124, 3, 70, 41, 0, "StyleData", "AddOnsLink", "Printout"],
Cell[74062, 2989, 132, 3, 70, 49, 0, "StyleData", "AddOnsLink", \
"EnhancedPrintout"],
Cell[74197, 2994, 139, 3, 70, 56, 0, "StyleData", "AddOnsLink", \
"EnhancedPrintoutNonGray"]
}, Closed]],

Cell[CellGroupData[{
Cell[74373, 3002, 339, 9, 38, 33, 0, "StyleData", "AddOnsLinkText", "All",
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic],
Cell[74715, 3013, 128, 3, 70, 45, 0, "StyleData", "AddOnsLinkText", \
"Printout"],
Cell[74846, 3018, 136, 3, 70, 53, 0, "StyleData", "AddOnsLinkText", \
"EnhancedPrintout"],
Cell[74985, 3023, 143, 3, 70, 60, 0, "StyleData", "AddOnsLinkText", \
"EnhancedPrintoutNonGray"]
}, Closed]],

Cell[CellGroupData[{
Cell[75165, 3031, 341, 9, 37, 31, 0, "StyleData", "RefGuideLink", "All",
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic],
Cell[75509, 3042, 126, 3, 70, 43, 0, "StyleData", "RefGuideLink", \
"Printout"],
Cell[75638, 3047, 162, 4, 70, 51, 0, "StyleData", "RefGuideLink", \
"EnhancedPrintout"],
Cell[75803, 3053, 169, 4, 70, 58, 0, "StyleData", "RefGuideLink", \
"EnhancedPrintoutNonGray"]
}, Closed]],

Cell[CellGroupData[{
Cell[76009, 3062, 328, 8, 38, 37, 0, "StyleData", "GettingStartedLink", "All",
  
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic],
Cell[76340, 3072, 132, 3, 70, 49, 0, "StyleData", "GettingStartedLink", \
"Printout"],
Cell[76475, 3077, 166, 4, 70, 57, 0, "StyleData", "GettingStartedLink", \
"EnhancedPrintout"],
Cell[76644, 3083, 173, 4, 70, 64, 0, "StyleData", "GettingStartedLink", \
"EnhancedPrintoutNonGray"]
}, Closed]],

Cell[CellGroupData[{
Cell[76854, 3092, 332, 8, 38, 39, 0, "StyleData", "OtherInformationLink", \
"All",
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic],
Cell[77189, 3102, 134, 3, 70, 51, 0, "StyleData", "OtherInformationLink", \
"Printout"],
Cell[77326, 3107, 168, 4, 70, 59, 0, "StyleData", "OtherInformationLink", \
"EnhancedPrintout"],
Cell[77497, 3113, 175, 4, 70, 66, 0, "StyleData", "OtherInformationLink", \
"EnhancedPrintoutNonGray"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[77721, 3123, 33, 0, 36, "Section"],

Cell[CellGroupData[{
Cell[77779, 3127, 264, 7, 70, 27, 0, "StyleData", "Outline1", "All",
  CounterIncrements->"Outline1"],
Cell[78046, 3136, 100, 1, 70, 39, 0, "StyleData", "Outline1", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[78183, 3142, 290, 8, 70, 27, 0, "StyleData", "Outline2", "All",
  CounterIncrements->"Outline2"],
Cell[78476, 3152, 126, 2, 70, 39, 0, "StyleData", "Outline2", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[78639, 3159, 232, 6, 70, 27, 0, "StyleData", "Outline3", "All",
  CounterIncrements->"Outline3"],
Cell[78874, 3167, 89, 1, 70, 39, 0, "StyleData", "Outline3", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[79000, 3173, 269, 7, 70, 27, 0, "StyleData", "Outline4", "All",
  CounterIncrements->"Outline4"],
Cell[79272, 3182, 39, 0, 70, 39, 0, "StyleData", "Outline4", "Printout"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[79360, 3188, 30, 0, 36, "Section"],

Cell[CellGroupData[{
Cell[79415, 3192, 205, 6, 38, 32, 0, "StyleData", "BilateralCell", "All",
  StyleMenuListing->None],
Cell[79623, 3200, 115, 2, 52, 45, 0, "StyleData", "BilateralCell", \
"SlideShow"],
Cell[79741, 3204, 117, 3, 39, 44, 0, "StyleData", "BilateralCell", \
"Printout"],
Cell[79861, 3209, 151, 4, 40, 52, 0, "StyleData", "BilateralCell", \
"EnhancedPrintout"],
Cell[80015, 3215, 158, 4, 40, 59, 0, "StyleData", "BilateralCell", \
"EnhancedPrintoutNonGray"]
}, Closed]],

Cell[CellGroupData[{
Cell[80210, 3224, 155, 4, 41, 33, 0, "StyleData", "RuledPageBreak", "All"],
Cell[80368, 3230, 81, 1, 33, 46, 0, "StyleData", "RuledPageBreak", \
"SlideShow"],
Cell[80452, 3233, 117, 3, 30, 45, 0, "StyleData", "RuledPageBreak", \
"Printout"],
Cell[80572, 3238, 110, 2, 37, 53, 0, "StyleData", "RuledPageBreak", \
"EnhancedPrintout"],
Cell[80685, 3242, 117, 2, 37, 60, 0, "StyleData", "RuledPageBreak", \
"EnhancedPrintoutNonGray"]
}, Closed]],
Cell[80817, 3247, 306, 10, 38, 39, 0, "StyleData", "PaletteHeadingButton", \
"All",
  StyleMenuListing->None,
  ButtonStyleMenuListing->None],
Cell[81126, 3259, 299, 9, 38, 32, 0, "StyleData", "PaletteButton", "All",
  StyleMenuListing->None,
  ButtonStyleMenuListing->None],
Cell[81428, 3270, 295, 9, 38, 33, 0, "StyleData", "PaletteButton2", "All",
  StyleMenuListing->None,
  ButtonStyleMenuListing->None]
}, Closed]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

